@@ -10,6 +10,7 @@ namespace Piwik\API;
 
 use Exception;
 use Piwik\Archive\DataTableFactory;
+use Piwik\Container\StaticContainer;
 use Piwik\DataTable\Row;
 use Piwik\DataTable;
 use Piwik\Period\Range;
@@ -153,11 +154,11 @@ abstract class DataTableManipulator
             }
 
             $apiParameters = array();
-            if (!empty($request['idDimension'])) {
-                $apiParameters['idDimension'] = $request['idDimension'];
-            }
-            if (!empty($request['idGoal'])) {
-                $apiParameters['idGoal'] = $request['idGoal'];
+            $entityNames = StaticContainer::get('entities.idNames');
+            foreach ($entityNames as $idName) {
+                if (!empty($request[$idName])) {
+                    $apiParameters[$idName] = $request[$idName];
+                }
             }
 
             $meta = API::getInstance()->getMetadata($idSite, $this->apiModule, $this->apiMethod, $apiParameters);
@@ -169,7 +170,7 @@ abstract class DataTableManipulator
 
             if (empty($meta)) {
                 throw new Exception(sprintf(
-                    "The DataTable cannot be manipulated: Metadata for report %s.%s could not be found. You can define the metadata in a hook, see example at: http://developer.piwik.org/api-reference/events#apigetreportmetadata",
+                    "The DataTable cannot be manipulated: Metadata for report %s.%s could not be found. You can define the metadata in a hook, see example at: https://developer.matomo.org/api-reference/events#apigetreportmetadata",
                     $this->apiModule, $this->apiMethod
                 ));
             }
