@@ -31,12 +31,15 @@ class Inconsistencies
         return array(
             'bounce_rate',
             'conversion_rate',
+            'abandoned_rate',
             'interaction_rate',
             'exit_rate',
             'bounce_rate_returning',
             'nb_visits_percentage',
             '/.*_evolution/',
-            '/goal_.*_conversion_rate/'
+            '/goal_.*_conversion_rate/',
+            '/form_.*_rate/',
+            '/field_.*_rate/',
         );
     }
 }
