@@ -164,6 +164,8 @@ class Proxy extends Singleton
             // allow plugins to manipulate the value
             $pluginName = $this->getModuleNameFromClassName($className);
 
+            $returnedValue = null;
+
             /**
              * Triggered before an API request is dispatched.
              *
@@ -207,6 +209,20 @@ class Proxy extends Singleton
              */
             Piwik::postEvent(sprintf('API.%s.%s', $pluginName, $methodName), array(&$finalParameters));
 
+            /**
+             * Triggered before an API request is dispatched.
+             *
+             * Use this event to intercept an API request and execute your own code instead. If you set
+             * `$returnedValue` in a handler for this event, the original API method will not be executed,
+             * and the result will be what you set in the event handler.
+             *
+             * @param mixed &$returnedValue Set this to set the result and preempt normal API invocation.
+             * @param array &$finalParameters List of parameters that will be passed to the API method.
+             * @param string $pluginName The name of the plugin the API method belongs to.
+             * @param string $methodName The name of the API method that will be called.
+             */
+            Piwik::postEvent(sprintf('API.Request.intercept'), [&$returnedValue, $finalParameters, $pluginName, $methodName]);
+
             $apiParametersInCorrectOrder = array();
 
             foreach ($parameterNamesDefaultValues as $name => $defaultValue) {
@@ -215,8 +231,10 @@ class Proxy extends Singleton
                 }
             }
 
-            // call the method
-            $returnedValue = call_user_func_array(array($object, $methodName), $apiParametersInCorrectOrder);
+            // call the method if a hook hasn't already set an output variable
+            if ($returnedValue === null) {
+                $returnedValue = call_user_func_array(array($object, $methodName), $apiParametersInCorrectOrder);
+            }
 
             $endHookParams = array(
                 &$returnedValue,
