@@ -35,22 +35,16 @@ class Parameters
      */
     private $segment;
 
-    /**
-     * @var bool
-     */
-    private $skipAggregationOfSubTables;
-
     public function getSegment()
     {
         return $this->segment;
     }
 
-    public function __construct($idSites, $periods, Segment $segment, $skipAggregationOfSubTables)
+    public function __construct($idSites, $periods, Segment $segment)
     {
         $this->idSites = $idSites;
         $this->periods = $periods;
         $this->segment = $segment;
-        $this->skipAggregationOfSubTables = $skipAggregationOfSubTables;
     }
 
     public function getPeriods()
@@ -62,11 +56,4 @@ class Parameters
     {
         return $this->idSites;
     }
-
-    public function isSkipAggregationOfSubTables()
-    {
-        return $this->skipAggregationOfSubTables;
-    }
-
 }
-
