@@ -10,7 +10,10 @@ namespace Piwik\ArchiveProcessor;
 
 use Piwik\Archive;
 use Piwik\Cache;
+use Piwik\CacheId;
+use Piwik\Common;
 use Piwik\Config;
+use Piwik\Context;
 use Piwik\DataAccess\ArchiveSelector;
 use Piwik\Date;
 use Piwik\Period;
@@ -62,6 +65,13 @@ class Loader
     }
 
     public function prepareArchive($pluginName)
+    {
+        return Context::changeIdSite($this->params->getSite()->getId(), function () use ($pluginName) {
+            return $this->prepareArchiveImpl($pluginName);
+        });
+    }
+
+    private function prepareArchiveImpl($pluginName)
     {
         $this->params->setRequestedPlugin($pluginName);
 
