@@ -37,7 +37,7 @@ abstract class UIAssetFetcher
      * @param string[] $plugins
      * @param Theme $theme
      */
-    function __construct($plugins, $theme)
+    public function __construct($plugins, $theme)
     {
         $this->plugins = $plugins;
         $this->theme = $theme;
@@ -56,8 +56,9 @@ abstract class UIAssetFetcher
      */
     public function getCatalog()
     {
-        if($this->catalog == null)
+        if ($this->catalog == null) {
             $this->createCatalog();
+        }
 
         return $this->catalog;
     }
@@ -89,7 +90,6 @@ abstract class UIAssetFetcher
     private function populateCatalog()
     {
         foreach ($this->fileLocations as $fileLocation) {
-
             $newUIAsset = new OnDiskUIAsset($this->getBaseDirectory(), $fileLocation);
             $this->catalog->addUIAsset($newUIAsset);
         }
@@ -106,7 +106,7 @@ abstract class UIAssetFetcher
     private function getBaseDirectory()
     {
         // served by web server directly, so must be a public path
-        return PIWIK_USER_PATH;
+        return PIWIK_DOCUMENT_ROOT;
     }
 
     /**
