@@ -232,7 +232,27 @@ class Common
             return mb_strtolower($string, 'UTF-8');
         }
 
-        return strtolower($string);
+        // return unchanged string as using `strtolower` might cause unicode problems
+        return $string;
+    }
+
+    /**
+     * Multi-byte strtoupper() - works with UTF-8.
+     *
+     * Calls `mb_strtoupper` if available and falls back to `strtoupper` if not.
+     *
+     * @param string $string
+     * @return string
+     * @api
+     */
+    public static function mb_strtoupper($string)
+    {
+        if (function_exists('mb_strtoupper')) {
+            return mb_strtoupper($string, 'UTF-8');
+        }
+
+        // return unchanged string as using `strtoupper` might cause unicode problems
+        return $string;
     }
 
     /*
@@ -1026,6 +1046,10 @@ class Common
 
         $countryList = $dataProvider->getCountryList();
 
+        if ($country == 'ti') {
+            $country = 'cn';
+        }
+
         return isset($countryList[$country]) ? $countryList[$country] : 'unk';
     }
 
@@ -1118,6 +1142,19 @@ class Common
         }
     }
 
+    /**
+     * Strips outgoing header.
+     *
+     * @param string $name The header name.
+     */
+    public static function stripHeader($name)
+    {
+        // don't strip header in CLI mode
+        if (!Common::isPhpCliMode() and !headers_sent()) {
+            header_remove($name);
+        }
+    }
+
     /**
      * Sends the given response code if supported.
      *
