@@ -12,6 +12,8 @@ namespace Piwik;
 use Exception;
 use Piwik\Application\Kernel\GlobalSettingsProvider;
 use Piwik\Container\StaticContainer;
+use Piwik\Exception\MissingFilePermissionException;
+use Piwik\ProfessionalServices\Advertising;
 
 /**
  * Singleton that provides read & write access to Piwik's INI configuration.
@@ -155,10 +157,11 @@ class Config
 
         return array(
             'action_url_category_delimiter' => $general['action_url_category_delimiter'],
+            'action_title_category_delimiter' => $general['action_title_category_delimiter'],
             'autocomplete_min_sites' => $general['autocomplete_min_sites'],
             'datatable_export_range_as_day' => $general['datatable_export_range_as_day'],
             'datatable_row_limits' => $this->getDatatableRowLimits(),
-            'are_ads_enabled' => $general['piwik_pro_ads_enabled']
+            'are_ads_enabled' => Advertising::isAdsEnabledInConfig($general)
         );
     }
 
@@ -222,7 +225,7 @@ class Config
 
         $filename = $hostConfig['file'];
         if (!Filesystem::isValidFilename($filename)) {
-            throw new Exception('Piwik domain is not a valid looking hostname (' . $filename . ').');
+            throw new Exception('Matomo domain is not a valid looking hostname (' . $filename . ').');
         }
 
         $pathLocal = $hostConfig['path'];
@@ -356,7 +359,7 @@ class Config
         $chain = $this->settings->getIniFileChain();
 
         $header = "; <?php exit; ?> DO NOT REMOVE THIS LINE\n";
-        $header .= "; file automatically generated or modified by Piwik; you can manually override the default values in global.ini.php by redefining them in this file.\n";
+        $header .= "; file automatically generated or modified by Matomo; you can manually override the default values in global.ini.php by redefining them in this file.\n";
         return $chain->dumpChanges($header);
     }
 
@@ -374,18 +377,29 @@ class Config
      */
     protected function writeConfig($clear = true)
     {
-        if ($this->doNotWriteConfigInTests) {
-            return;
-        }
-
         $output = $this->dumpConfig();
         if ($output !== null
             && $output !== false
         ) {
-            $success = @file_put_contents($this->getLocalPath(), $output);
+            $localPath = $this->getLocalPath();
+
+            if ($this->doNotWriteConfigInTests) {
+                // simulate whether it would be successful
+                $success = is_writable($localPath);
+            } else {
+                $success = @file_put_contents($localPath, $output);
+            }
+
             if ($success === false) {
                 throw $this->getConfigNotWritableException();
             }
+
+            /**
+             * Triggered when a INI config file is changed on disk.
+             *
+             * @param string $localPath Absolute path to the changed file on the server.
+             */
+            Piwik::postEvent('Core.configFileChanged', [$localPath]);
         }
 
         if ($clear) {
@@ -410,6 +424,6 @@ class Config
     public function getConfigNotWritableException()
     {
         $path = "config/" . basename($this->getLocalPath());
-        return new Exception(Piwik::translate('General_ConfigFileIsNotWritable', array("(" . $path . ")", "")));
+        return new MissingFilePermissionException(Piwik::translate('General_ConfigFileIsNotWritable', array("(" . $path . ")", "")));
     }
 }
