@@ -101,27 +101,17 @@ class ColumnDelete extends BaseFilter
 
         // remove columns specified in $this->columnsToRemove
         if (!empty($this->columnsToRemove)) {
-            foreach ($table as $index => $row) {
-                foreach ($this->columnsToRemove as $column) {
-                    if ($this->deleteIfZeroOnly) {
-                        $value = $row[$column];
-                        if ($value === false || !empty($value)) {
-                            continue;
-                        }
-                    }
-
-                    unset($table[$index][$column]);
-                }
-            }
-
+            $this->removeColumnsFromTable($table);
             $recurse = true;
         }
 
         // remove columns not specified in $columnsToKeep
         if (!empty($this->columnsToKeep)) {
             foreach ($table as $index => $row) {
+                $columnsToDelete = array();
                 foreach ($row as $name => $value) {
                     $keep = false;
+
                     // @see self::APPEND_TO_COLUMN_NAME_TO_KEEP
                     foreach ($this->columnsToKeep as $nameKeep => $true) {
                         if (strpos($name, $nameKeep . self::APPEND_TO_COLUMN_NAME_TO_KEEP) === 0) {
@@ -133,9 +123,14 @@ class ColumnDelete extends BaseFilter
                         && $name != 'label' // label cannot be removed via whitelisting
                         && !isset($this->columnsToKeep[$name])
                     ) {
-                        unset($table[$index][$name]);
+                        // we cannot remove row directly to prevent notice "ArrayIterator::next(): Array was modified
+                        // outside object and internal position is no longer valid in /var/www..."
+                        $columnsToDelete[] = $name;
                     }
                 }
+                foreach ($columnsToDelete as $columnToDelete) {
+                    unset($table[$index][$columnToDelete]);
+                }
             }
 
             $recurse = true;
@@ -150,4 +145,47 @@ class ColumnDelete extends BaseFilter
 
         return $table;
     }
+
+    /**
+     * @param $table
+     * @return array
+     */
+    protected function removeColumnsFromTable(&$table)
+    {
+        if(!$this->isArrayAccess($table)) {
+            return;
+        }
+        foreach ($table as $index => $row) {
+            if(!$this->isArrayAccess($row)) {
+                continue;
+            }
+            foreach ($this->columnsToRemove as $column) {
+
+                if (!array_key_exists($column, $row)) {
+                    continue;
+                }
+
+                if ($this->deleteIfZeroOnly) {
+                    $value = $row[$column];
+                    if ($value === false || !empty($value)) {
+                        continue;
+                    }
+                }
+
+                unset($table[$index][$column]);
+            }
+
+            // Restore me in Piwik 4
+            //$this->removeColumnsFromTable($row);
+        }
+    }
+
+    /**
+     * @param $table
+     * @return bool
+     */
+    protected function isArrayAccess(&$table)
+    {
+        return is_array($table) || $table instanceof \ArrayAccess;
+    }
 }
