@@ -13,7 +13,6 @@ use Piwik\Common;
 use Piwik\Config;
 use Piwik\Container\StaticContainer;
 use Piwik\Db;
-use Piwik\DbHelper;
 use Piwik\Log;
 use Piwik\SettingsServer;
 
@@ -115,7 +114,7 @@ class BatchInsert
             // in this case tableInsertBatch might still work
         }
 
-        if (empty($path) || !is_dir($path) || !is_writable($path)) {
+        if (empty($path) || !@is_dir($path) || !@is_writable($path)) {
             $path = StaticContainer::get('path.tmp') . '/assets/';
         } elseif (!Common::stringEndsWith($path, '/')) {
             $path .= '/';
@@ -180,7 +179,11 @@ class BatchInsert
          * this requires that the db user have the FILE privilege; however, since this is
          * a global privilege, it may not be granted due to security concerns
          */
-        $keywords = array('');
+        if (Config::getInstance()->General['multi_server_environment']) {
+            $keywords = array(); // don't try 'LOAD DATA INFILE' if in a multi_server_environment
+        } else {
+            $keywords = array('');
+        }
 
         /*
          * Second attempt: using the LOCAL keyword means the client reads the file and sends it to the server;
@@ -188,10 +191,12 @@ class BatchInsert
          * @see http://bugs.php.net/bug.php?id=54158
          */
         $openBaseDir = ini_get('open_basedir');
-        $safeMode    = ini_get('safe_mode');
+        $isUsingNonBuggyMysqlnd = function_exists('mysqli_get_client_stats') && version_compare(PHP_VERSION, '5.6.17', '>=');
+        $safeMode = ini_get('safe_mode');
 
-        if (empty($openBaseDir) && empty($safeMode)) {
-            // php 5.x - LOAD DATA LOCAL INFILE is disabled if open_basedir restrictions or safe_mode enabled
+        if (($isUsingNonBuggyMysqlnd || empty($openBaseDir)) && empty($safeMode)) {
+            // php 5.x - LOAD DATA LOCAL INFILE only used if open_basedir is not set (or we're using a non-buggy version of mysqlnd)
+            //           and if safe mode is not enabled
             $keywords[] = 'LOCAL ';
         }
 
