@@ -31,6 +31,18 @@ class Filesystem
         TrackerCache::deleteTrackerCache();
         PiwikCache::flushAll();
         self::clearPhpCaches();
+        
+        $pluginManager = Plugin\Manager::getInstance();
+        $plugins = $pluginManager->getLoadedPlugins();
+        foreach ($plugins as $plugin) {
+            $plugin->reloadPluginInformation();
+        }
+
+        /**
+         * Triggered after all non-memory caches are cleared (eg, via the cache:clear
+         * command).
+         */
+        Piwik::postEvent('Filesystem.allCachesCleared');
     }
 
     /**
@@ -177,6 +189,7 @@ class Filesystem
                 $aFiles = array_merge($aFiles, $aSubFiles);
             }
         }
+        sort($aFiles);
         return $aFiles;
     }
 
