@@ -36,8 +36,10 @@ class PeriodValidator
     public function getPeriodsAllowedForUI()
     {
         $periodsAllowed = Config::getInstance()->General['enabled_periods_UI'];
-
-        return array_map('trim', explode(',', $periodsAllowed));
+        $periodsAllowed = array_map('trim', explode(',', $periodsAllowed));
+        $periodsAllowed = array_unique($periodsAllowed);
+        $periodsAllowed = array_values($periodsAllowed);
+        return $periodsAllowed;
     }
 
     /**
@@ -46,7 +48,9 @@ class PeriodValidator
     public function getPeriodsAllowedForAPI()
     {
         $periodsAllowed = Config::getInstance()->General['enabled_periods_API'];
-
-        return array_map('trim', explode(',', $periodsAllowed));
+        $periodsAllowed = array_map('trim', explode(',', $periodsAllowed));
+        $periodsAllowed = array_unique($periodsAllowed);
+        $periodsAllowed = array_values($periodsAllowed);
+        return $periodsAllowed;
     }
 }
