@@ -77,11 +77,18 @@ class Piwik
     {
         Common::sendHeader('Content-Type: text/html; charset=utf-8');
 
-        $output = "<style>a{color:red;}</style>\n" .
-            "<div style='color:red;font-size:120%'>" .
-            "<p><img src='plugins/Morpheus/images/error_medium.png' style='vertical-align:middle; float:left;padding:20px' />" .
+        $message = str_replace("\n", "<br/>", $message);
+
+        $output = "<html><body>".
+            "<style>a{color:red;}</style>\n" .
+            "<div style='color:red;font-size:120%; width:100%;margin: 30px;'>" .
+            " <div style='width: 50px; float: left;'><img src='plugins/Morpheus/images/error_medium.png' /></div>" .
+            "  <div style='margin-left: 70px; min-width: 950px;'>" .
             $message .
-            "</p></div>";
+            "  </div>" .
+            " </div>" .
+            "</div>".
+            "</body></html>";
         print($output);
         exit;
     }
@@ -313,7 +320,8 @@ class Piwik
     public static function isUserIsAnonymous()
     {
         $currentUserLogin = Piwik::getCurrentUserLogin();
-        return $currentUserLogin == 'anonymous';
+        $isSuperUser = self::hasUserSuperUserAccess();
+        return !$isSuperUser && $currentUserLogin == 'anonymous';
     }
 
     /**
@@ -589,7 +597,7 @@ class Piwik
         $l = strlen($userLogin);
         if (!($l >= $loginMinimumLength
             && $l <= $loginMaximumLength
-            && (preg_match('/^[A-Za-z0-9_.@+-]*$/D', $userLogin) > 0))
+            && (preg_match('/^[A-Za-zÄäÖöÜüß0-9_.@+-]*$/D', $userLogin) > 0))
         ) {
             throw new Exception(Piwik::translate('UsersManager_ExceptionInvalidLoginFormat', array($loginMinimumLength, $loginMaximumLength)));
         }
@@ -722,7 +730,7 @@ class Piwik
 
     /**
      * Returns an internationalized string using a translation token. If a translation
-     * cannot be found for the toke, the token is returned.
+     * cannot be found for the token, the token is returned.
      *
      * @param string $translationId Translation ID, eg, `'General_Date'`.
      * @param array|string|int $args `sprintf` arguments to be applied to the internationalized
