@@ -202,6 +202,33 @@ class Segment
         return $this->sqlSegment;
     }
 
+    /**
+     * @return string
+     * @ignore
+     */
+    public function getSqlFilterValue()
+    {
+        return $this->sqlFilterValue;
+    }
+
+    /**
+     * @return string
+     * @ignore
+     */
+    public function getAcceptValues()
+    {
+        return $this->acceptValues;
+    }
+
+    /**
+     * @return string
+     * @ignore
+     */
+    public function getSqlFilter()
+    {
+        return $this->sqlFilter;
+    }
+
     /**
      * Set (overwrite) the type of this segment which is usually either a 'dimension' or a 'metric'.
      * @param string $type See constansts TYPE_*
@@ -230,6 +257,15 @@ class Segment
         return $this->name;
     }
 
+    /**
+     * @return string
+     * @ignore
+     */
+    public function getCategoryId()
+    {
+        return $this->category;
+    }
+
     /**
      * Returns the name of this segment as it should appear in segment expressions.
      *
@@ -240,6 +276,15 @@ class Segment
         return $this->segment;
     }
 
+    /**
+     * @return string
+     * @ignore
+     */
+    public function getSuggestedValuesCallback()
+    {
+        return $this->suggestedValuesCallback;
+    }
+
     /**
      * Set callback which will be executed when user will call for suggested values for segment.
      *
