@@ -107,6 +107,16 @@ class Segment
         }
     }
 
+    /**
+     * Returns the segment expression.
+     * @return SegmentExpression
+     * @api since Piwik 3.2.0
+     */
+    public function getSegmentExpression()
+    {
+        return $this->segmentExpression;
+    }
+
     private function getAvailableSegments()
     {
         // segment metadata
@@ -253,7 +263,7 @@ class Segment
             && $matchType != SegmentExpression::MATCH_IS_NULL_OR_EMPTY) {
 
             if (isset($segment['sqlFilterValue'])) {
-                $value = call_user_func($segment['sqlFilterValue'], $value);
+                $value = call_user_func($segment['sqlFilterValue'], $value, $segment['sqlSegment']);
             }
 
             // apply presentation filter
