@@ -45,6 +45,16 @@ class SettingsPiwik
         return Config::getInstance()->General['disable_checks_usernames_attributes'] == 0;
     }
 
+    /**
+     * Should Piwik show the update notification to superusers only?
+     *
+     * @return bool  True if show to superusers only; false otherwise
+     */
+    public static function isShowUpdateNotificationToSuperUsersOnlyEnabled()
+    {
+        return Config::getInstance()->General['show_update_notification_to_superusers_only'] == 1;
+    }
+
     /**
      * Returns every stored segment to pre-process for each site during cron archiving.
      *
@@ -234,6 +244,17 @@ class SettingsPiwik
         return true;
     }
 
+    /**
+     * Check if outgoing internet connections are enabled
+     * This is often disable in an intranet environment
+     * 
+     * @return bool
+     */
+    public static function isInternetEnabled()
+    {
+        return (bool) Config::getInstance()->General['enable_internet_features'];
+    }
+    
     /**
      * Detect whether user has enabled auto updates. Please note this config is a bit misleading. It is currently
      * actually used for 2 things: To disable making any connections back to Piwik, and to actually disable the auto
@@ -242,7 +263,12 @@ class SettingsPiwik
      */
     public static function isAutoUpdateEnabled()
     {
-        return (bool) Config::getInstance()->General['enable_auto_update'];
+        $enableAutoUpdate = (bool) Config::getInstance()->General['enable_auto_update'];
+        if(self::isInternetEnabled() === true && $enableAutoUpdate === true){
+            return true;
+        }
+        
+        return false;
     }
 
     /**
@@ -367,7 +393,7 @@ class SettingsPiwik
         $hasError = false !== strpos($fetched, PAGE_TITLE_WHEN_ERROR);
 
         if ($hasError || $expectedStringNotFound) {
-            throw new Exception("\nPiwik should be running at: "
+            throw new Exception("\nMatomo should be running at: "
                 . $piwikServerUrl
                 . " but this URL returned an unexpected response: '"
                 . $fetched . "'\n\n");
