@@ -22,7 +22,7 @@ class IgnoreCookie
      *
      * @return Cookie
      */
-    public static function getTrackingCookie()
+    private static function getTrackingCookie()
     {
         $cookie_name = @Config::getInstance()->Tracker['cookie_name'];
         $cookie_path = @Config::getInstance()->Tracker['cookie_path'];
@@ -30,6 +30,14 @@ class IgnoreCookie
         return new Cookie($cookie_name, null, $cookie_path);
     }
 
+    public static function deleteThirdPartyCookieUIDIfExists()
+    {
+        $trackingCookie = self::getTrackingCookie();
+        if ($trackingCookie->isCookieFound()) {
+            $trackingCookie->delete();
+        }
+    }
+
     /**
      * Get ignore (visit) cookie
      *
@@ -54,10 +62,9 @@ class IgnoreCookie
         } else {
             $ignoreCookie->set('ignore', '*');
             $ignoreCookie->save();
-
-            $trackingCookie = self::getTrackingCookie();
-            $trackingCookie->delete();
         }
+
+        self::deleteThirdPartyCookieUIDIfExists();
     }
 
     /**
