@@ -58,6 +58,10 @@ class ReferrerSpamFilter
             $cache->save($cacheId, $list);
         }
 
+        if(!is_array($list)) {
+            Common::printDebug('Warning: could not read list of spammers from cache.');
+            return array();
+        }
         return $list;
     }
 
@@ -74,7 +78,7 @@ class ReferrerSpamFilter
             $this->spammerList = unserialize($list);
         } else {
             // Fallback to reading the bundled list
-            $file = PIWIK_VENDOR_PATH . '/piwik/referrer-spam-blacklist/spammers.txt';
+            $file = PIWIK_VENDOR_PATH . '/matomo/referrer-spam-blacklist/spammers.txt';
             $this->spammerList = file($file, FILE_IGNORE_NEW_LINES | FILE_SKIP_EMPTY_LINES);
         }
 
