@@ -11,6 +11,7 @@ namespace Piwik\ViewDataTable;
 
 use Piwik\API\Request as ApiRequest;
 use Piwik\Common;
+use Piwik\Container\StaticContainer;
 use Piwik\DataTable;
 use Piwik\DataTable\Filter\PivotByDimension;
 use Piwik\Metrics;
@@ -82,7 +83,7 @@ use Piwik\Plugin\ReportsProvider;
  *
  * @api
  */
-class Config
+class   Config
 {
     /**
      * The list of ViewDataTable properties that are 'Client Side Properties'.
@@ -91,7 +92,8 @@ class Config
         'show_limit_control',
         'pivot_by_dimension',
         'pivot_by_column',
-        'pivot_dimension_name'
+        'pivot_dimension_name',
+        'disable_all_rows_filter_limit',
     );
 
     /**
@@ -110,6 +112,7 @@ class Config
         'show_related_reports',
         'show_limit_control',
         'show_search',
+        'show_export',
         'enable_sort',
         'show_bar_chart',
         'show_pie_chart',
@@ -121,7 +124,6 @@ class Config
         'show_pagination_control',
         'show_offset_information',
         'hide_annotations_view',
-        'export_limit',
         'columns_to_display'
     );
 
@@ -320,6 +322,13 @@ class Config
      */
     public $show_search = true;
 
+    /**
+     * Controls whether the export feature under the datatable is shown.
+     *
+     * @api since Piwik 3.2.0
+     */
+    public $show_export = true;
+
     /**
      * Controls whether the user can sort DataTables by clicking on table column headings.
      */
@@ -363,8 +372,17 @@ class Config
      */
     public $show_ecommerce = false;
 
+    /**
+     * Stores an HTML message (if any) to display above the datatable view.
+     *
+     * Attention: Message will be printed raw. Don't forget to escape where needed!
+     */
+    public $show_header_message = false;
+
     /**
      * Stores an HTML message (if any) to display under the datatable view.
+     *
+     * Attention: Message will be printed raw. Don't forget to escape where needed!
      */
     public $show_footer_message = false;
 
@@ -456,11 +474,21 @@ class Config
     public $hide_annotations_view = true;
 
     /**
-     * The filter_limit query parameter value to use in export links.
+     * Controls whether the 'all' row limit option is shown for the limit selector.
      *
-     * Defaulted to the value of the `[General] API_datatable_default_limit` INI config option.
+     * @var bool
      */
-    public $export_limit = '';
+    public $disable_all_rows_filter_limit = false;
+
+    /**
+     * Message to show if not data is available for the report
+     * Defaults to `CoreHome_ThereIsNoDataForThisReport` if not set
+     *
+     * Attention: Message will be printed raw. Don't forget to escape where needed!
+     *
+     * @var string
+     */
+    public $no_data_message = '';
 
     /**
      * @ignore
@@ -482,7 +510,6 @@ class Config
      */
     public function __construct()
     {
-        $this->export_limit = \Piwik\Config::getInstance()->General['API_datatable_default_limit'];
         $this->translations = array_merge(
             Metrics::getDefaultMetrics(),
             Metrics::getDefaultProcessedMetrics()
@@ -517,13 +544,12 @@ class Config
         }
 
         $apiParameters = array();
-        $idDimension = Common::getRequestVar('idDimension', 0, 'int');
-        $idGoal = Common::getRequestVar('idGoal', 0, 'int');
-        if ($idDimension > 0) {
-            $apiParameters['idDimension'] = $idDimension;
-        }
-        if ($idGoal > 0) {
-            $apiParameters['idGoal'] = $idGoal;
+        $entityNames = StaticContainer::get('entities.idNames');
+        foreach ($entityNames as $entityName) {
+            $idEntity = Common::getRequestVar($entityName, 0, 'int');
+            if ($idEntity > 0) {
+                $apiParameters[$entityName] = $idEntity;
+            }
         }
 
         $report = API::getInstance()->getMetadata($idSite, $this->controllerName, $this->controllerAction, $apiParameters);
