@@ -106,12 +106,17 @@ class Factory
 
         $params = array();
 
-        if(is_null($loadViewDataTableParametersForUser)) {
+        if (!isset($loadViewDataTableParametersForUser)) {
             $loadViewDataTableParametersForUser = ('0' == Common::getRequestVar('widget', '0', 'string'));
         }
+
         if ($loadViewDataTableParametersForUser) {
             $login  = Piwik::getCurrentUserLogin();
-            $params = Manager::getViewDataTableParameters($login, $controllerAction);
+            $paramsKey = $controllerAction;
+            if (!empty($report) && $controllerAction === $apiAction) {
+                $paramsKey = $report->getId();
+            }
+            $params = Manager::getViewDataTableParameters($login, $paramsKey);
         }
 
         if (!self::isDefaultViewTypeForReportFixed($report)) {
