@@ -28,13 +28,14 @@ define('PIWIK_USER_PATH', '..');
 
 require_once PIWIK_INCLUDE_PATH . '/libs/upgradephp/upgrade.php';
 
-// Composer autoloader
-if (file_exists(PIWIK_INCLUDE_PATH . '/vendor/autoload.php')) {
-    $path = PIWIK_INCLUDE_PATH . '/vendor/autoload.php'; // Piwik is the main project
+if (is_dir(PIWIK_INCLUDE_PATH . '/vendor')) {
+    define('PIWIK_VENDOR_PATH', PIWIK_INCLUDE_PATH . '/vendor'); // Piwik is the main project
 } else {
-    $path = PIWIK_INCLUDE_PATH . '/../../autoload.php'; // Piwik is installed as a dependency
+    define('PIWIK_VENDOR_PATH', PIWIK_INCLUDE_PATH . '/../..'); // Piwik is installed as a Composer dependency
 }
-require $path;
+
+// Composer autoloader
+require PIWIK_VENDOR_PATH . '/autoload.php';
 
 $file = '../piwik.js';
 
@@ -44,9 +45,18 @@ $byteStart = $byteEnd = false;
 if (!defined("PIWIK_KEEP_JS_TRACKER_COMMENT")
     || !PIWIK_KEEP_JS_TRACKER_COMMENT
 ) {
-    $byteStart = 369; // length of comment header in bytes
+    $byteStart = 371; // length of comment header in bytes
 }
 
+class Validator {
+    public function validate() {}
+}
+$validator = new Validator();
+$environment = new \Piwik\Application\Environment(null, array(
+    'Piwik\Application\Kernel\EnvironmentValidator' => $validator
+));
+$environment->init();
+
 ProxyHttp::serverStaticFile($file, "application/javascript; charset=UTF-8", $daysExpireFarFuture, $byteStart, $byteEnd);
 
-exit;
\ No newline at end of file
+exit;
