@@ -72,7 +72,7 @@ class Zend_Validate_Int extends Zend_Validate_Abstract
         if (empty($locale)) {
             // require_once 'Zend/Registry.php';
             if (Zend_Registry::isRegistered('Zend_Locale')) {
-                $locale = Zend_Registry::get('Zend_Locale');
+                $locale = \Zend_Registry::get('Zend_Locale');
             }
         }
 
