@@ -40,7 +40,7 @@ if (Piwik\Common::isPhpCliMode()) {
 Using this 'archive.php' script is no longer recommended.
 Please use '/path/to/php $piwikHome/console core:archive " . implode(' ', $_SERVER['argv']) . "' instead.
 To get help use '/path/to/php $piwikHome/console core:archive --help'
-See also: http://piwik.org/docs/setup-auto-archiving/
+See also: https://matomo.org/docs/setup-auto-archiving/
 
 If you cannot use the console because it requires CLI
 try 'php archive.php --url=http://your.piwik/path'
@@ -60,7 +60,7 @@ try 'php archive.php --url=http://your.piwik/path'
     if(!isset($_GET['token_auth'])) {
         echo "
 <b>You must specify the Super User token_auth as a parameter to this script, eg. <code>?token_auth=XYZ</code> if you wish to run this script through the browser. </b><br>
-However it is recommended to run it <a href='http://piwik.org/docs/setup-auto-archiving/'>via cron in the command line</a>, since it can take a long time to run.<br/>
+However it is recommended to run it <a href='https://matomo.org/docs/setup-auto-archiving/'>via cron in the command line</a>, since it can take a long time to run.<br/>
 In a shell, execute for example the following to trigger archiving on the local Piwik server:<br/>
 <code>$ /path/to/php /path/to/piwik/console core:archive --url=http://your-website.org/path/to/piwik/</code>
 \n\n";
