@@ -12,6 +12,9 @@ use Piwik\SettingsServer;
 use Piwik\Tracker\RequestSet;
 use Piwik\Tracker;
 use Piwik\Tracker\Handler;
+use Piwik\API\CORSHandler;
+
+@ignore_user_abort(true);
 
 // Note: if you wish to debug the Tracking API please see this documentation:
 // http://developer.piwik.org/api-reference/tracking-api#debugging-the-tracker
@@ -28,8 +31,6 @@ if (!defined('PIWIK_INCLUDE_PATH')) {
 
 require_once PIWIK_INCLUDE_PATH . '/core/bootstrap.php';
 
-@ignore_user_abort(true);
-
 require_once PIWIK_INCLUDE_PATH . '/core/Plugin/Controller.php';
 require_once PIWIK_INCLUDE_PATH . '/core/Exception/NotYetInstalledException.php';
 require_once PIWIK_INCLUDE_PATH . '/core/Plugin/ControllerAdmin.php';
@@ -49,6 +50,7 @@ require_once PIWIK_INCLUDE_PATH . '/core/Translate.php';
 require_once PIWIK_INCLUDE_PATH . '/core/Tracker/Cache.php';
 require_once PIWIK_INCLUDE_PATH . '/core/Tracker/Request.php';
 require_once PIWIK_INCLUDE_PATH . '/core/Cookie.php';
+require_once PIWIK_INCLUDE_PATH . '/core/API/CORSHandler.php';
 
 SettingsServer::setIsTrackerApiRequest();
 
@@ -61,6 +63,9 @@ try {
 
 Tracker::loadTrackerEnvironment();
 
+$corsHandler = new CORSHandler();
+$corsHandler->handle();
+
 $tracker    = new Tracker();
 $requestSet = new RequestSet();
 
@@ -81,4 +86,4 @@ try {
 
 if (ob_get_level() > 1) {
     ob_end_flush();
-}
\ No newline at end of file
+}
