@@ -49,9 +49,11 @@ class Controller extends \Piwik\Plugin\Controller
 
     public function listAllMethods()
     {
+        Piwik::checkUserHasSomeViewAccess();
+
         $ApiDocumentation = new DocumentationGenerator();
-        $prefixUrls = Common::getRequestVar('prefixUrl', 'http://demo.piwik.org/', 'string');
-        if (!UrlHelper::isLookLikeUrl($prefixUrls)) {
+        $prefixUrls = Common::getRequestVar('prefixUrl', 'https://demo.matomo.org/', 'string');
+        if (!UrlHelper::isLookLikeUrl($prefixUrls) || strpos($prefixUrls, 'http') !== 0) {
             $prefixUrls = '';
         }
         return $ApiDocumentation->getApiDocumentationAsStringForDeveloperReference($outputExampleUrls = true, $prefixUrls);
@@ -76,12 +78,6 @@ class Controller extends \Piwik\Plugin\Controller
         $customVariables = 0;
         $lastCategory = array();
         foreach ($segments as $segment) {
-            // Eg. Event Value is a metric, not in the Visit metric category,
-            // we make sure it is displayed along with the Events dimensions
-            if ($segment['type'] == 'metric' && $segment['category'] != Piwik::translate('General_Visit')) {
-                $segment['type'] = 'dimension';
-            }
-
             $onlyDisplay = array('customVariableName1', 'customVariableName2',
                                  'customVariableValue1', 'customVariableValue2',
                                  'customVariablePageName1', 'customVariablePageValue1');
@@ -151,8 +147,8 @@ class Controller extends \Piwik\Plugin\Controller
         Piwik::checkUserHasSomeViewAccess();
 
         return $this->renderTemplate('glossary', array(
-            'reports' => Request::processRequest('API', array('method' => 'API.getGlossaryReports')),
-            'metrics' => Request::processRequest('API', array('method' => 'API.getGlossaryMetrics')),
+            'reports' => Request::processRequest('API', array('method' => 'API.getGlossaryReports', 'filter_limit' => -1)),
+            'metrics' => Request::processRequest('API', array('method' => 'API.getGlossaryMetrics', 'filter_limit' => -1)),
         ));
     }
 }
