@@ -10,11 +10,13 @@ namespace Piwik\Plugins\API\Renderer;
 
 use Piwik\API\ApiRenderer;
 use Piwik\Common;
-use Piwik\DataTable\Renderer;
-use Piwik\DataTable;
 
 class Html extends ApiRenderer
 {
+    public function renderSuccess($message)
+    {
+        return "<!-- Success: $message -->";
+    }
 
     /**
      * @param $message
