@@ -27,10 +27,10 @@ use Piwik\Tracker\Action;
 use Piwik\Tracker\PageUrl;
 
 /**
- * The Actions API lets you request reports for all your Visitor Actions: Page URLs, Page titles (Piwik Events),
+ * The Actions API lets you request reports for all your Visitor Actions: Page URLs, Page titles, Events, Content Tracking,
  * File Downloads and Clicks on external websites.
  *
- * For example, "getPageTitles" will return all your page titles along with standard <a href='http://piwik.org/docs/analytics-api/reference/#toc-metric-definitions' rel='noreferrer' target='_blank'>Actions metrics</a> for each row.
+ * For example, "getPageTitles" will return all your page titles along with standard <a href='http://matomo.org/docs/analytics-api/reference/#toc-metric-definitions' rel='noreferrer' target='_blank'>Actions metrics</a> for each row.
  *
  * It is also possible to request data for a specific Page Title with "getPageTitle"
  * and setting the parameter pageName to the page title you wish to request.
@@ -95,6 +95,17 @@ class API extends \Piwik\Plugin\API
 
         $this->filterActionsDataTable($dataTable);
 
+        if ($flat) {
+            $dataTable->filter(function(DataTable $dataTable) {
+                foreach ($dataTable->getRows() as $row) {
+                    $label = $row->getColumn('label');
+                    if (substr($label, 0, 1) !== '/' && $label != Piwik::translate('General_NotDefined', Piwik::translate('Actions_ColumnPageURL'))) {
+                        $row->setColumn('label', '/'.$label);
+                    }
+                }
+            });
+        }
+
         return $dataTable;
     }
 
