@@ -13,8 +13,6 @@ use Piwik\Piwik;
 
 class DestinationPage extends Dimension
 {
-    public function getName()
-    {
-        return Piwik::translate('General_ColumnDestinationPage');
-    }
+    protected $type = self::TYPE_TEXT;
+    protected $nameSingular = 'General_ColumnDestinationPage';
 }
\ No newline at end of file
