@@ -32,7 +32,7 @@ $(document).ready(function () {
         '"config/config.ini.php"',
         '"assume_secure_protocol=1"',
         '"[General]"',
-        '<a href="?module=Proxy&action=redirect&url=https://piwik.org/faq/how-to-install/faq_98/" target="_blank">',
+        '<a href="?module=Proxy&action=redirect&url=https://matomo.org/faq/how-to-install/faq_98/" target="_blank">',
         '</a>'
     ];
     var message = _pk_translate('CoreAdminHome_ProtocolNotDetectedCorrectly') + " " + _pk_translate('CoreAdminHome_ProtocolNotDetectedCorrectlySolution', params);
