@@ -82,10 +82,6 @@ class GenerateUpdate extends GeneratePluginBase
         $className = str_replace('Updates_xx', '', $className);
         $className = trim($className, '\\');
 
-        if ($component !== 'core') {
-            $className .= '\Updates';
-        }
-
         return $className;
     }
 
