@@ -9,7 +9,6 @@
 namespace Piwik\Plugins\CoreHome\Columns;
 
 use Piwik\Plugin\Dimension\VisitDimension;
-use Piwik\Plugins\CoreHome\Segment;
 use Piwik\Tracker\Action;
 use Piwik\Tracker\Request;
 use Piwik\Tracker\Visitor;
@@ -18,16 +17,10 @@ class VisitorDaysSinceOrder extends VisitDimension
 {
     protected $columnName = 'visitor_days_since_order';
     protected $columnType = 'SMALLINT(5) UNSIGNED NULL';
-
-    protected function configureSegments()
-    {
-        $segment = new Segment();
-        $segment->setSegment('daysSinceLastEcommerceOrder');
-        $segment->setName('General_DaysSinceLastEcommerceOrder');
-        $segment->setType(Segment::TYPE_METRIC);
-
-        $this->addSegment($segment);
-    }
+    protected $segmentName = 'daysSinceLastEcommerceOrder';
+    protected $nameSingular = 'General_DaysSinceLastEcommerceOrder';
+    protected $category = 'General_Visitors'; // todo put into ecommerce category?
+    protected $type = self::TYPE_NUMBER;
 
     /**
      * @param Request $request
