@@ -12,7 +12,6 @@ use Exception;
 use Piwik\API\DataTablePostProcessor;
 use Piwik\API\Request;
 use Piwik\Common;
-use Piwik\DataTable;
 use Piwik\Date;
 use Piwik\Metrics;
 use Piwik\NumberFormatter;
@@ -85,7 +84,9 @@ class RowEvolution
     public function __construct($idSite, $date, $graphType = 'graphEvolution')
     {
         $this->apiMethod = Common::getRequestVar('apiMethod', '', 'string');
-        if (empty($this->apiMethod)) throw new Exception("Parameter apiMethod not set.");
+        if (empty($this->apiMethod)) {
+            throw new Exception("Parameter apiMethod not set.");
+        }
 
         $this->label = DataTablePostProcessor::getLabelFromRequest($_GET);
         if (!is_array($this->label)) {
@@ -98,6 +99,10 @@ class RowEvolution
         $this->period = Common::getRequestVar('period', '', 'string');
         PeriodFactory::checkPeriodIsEnabled($this->period);
 
+        if ($this->period != 'range' && !($date instanceof Date)) {
+            throw new Exception("Expected date to be an instance of \\Piwik\\Date");
+        }
+
         $this->idSite = $idSite;
         $this->graphType = $graphType;
 
@@ -130,7 +135,7 @@ class RowEvolution
         $metricsText = Piwik::translate('RowEvolution_AvailableMetrics');
         $popoverTitle = '';
         if ($this->rowLabel) {
-            $icon = $this->rowIcon ? '<img src="' . $this->rowIcon . '" alt="">' : '';
+            $icon = $this->rowIcon ? '<img height="16px" src="' . $this->rowIcon . '" alt="">' : '';
             $metricsText = sprintf(Piwik::translate('RowEvolution_MetricsFor'), $this->dimension . ': ' . $icon . ' ' . $this->rowLabel);
             $popoverTitle = $icon . ' ' . $this->rowLabel;
         }
@@ -204,7 +209,6 @@ class RowEvolution
         $view->config->show_goals = false;
         $view->config->show_search = false;
         $view->config->show_all_views_icons = false;
-        $view->config->show_active_view_icon = false;
         $view->config->show_related_reports  = false;
         $view->config->show_series_picker    = false;
         $view->config->show_footer_message   = false;
@@ -306,7 +310,7 @@ class RowEvolution
         ob_end_clean();
 
         // undo header change by sparkline renderer
-        header('Content-type: text/html');
+        Common::sendHeader('Content-type: text/html');
 
         // base64 encode the image and put it in an img tag
         $spark = base64_encode($spark);
