@@ -17,6 +17,11 @@ class Visit extends LogTable
         return 'log_visit';
     }
 
+    public function getIdColumn()
+    {
+        return 'idvisit';
+    }
+
     public function getColumnToJoinOnIdVisit()
     {
         return 'idvisit';
@@ -27,4 +32,8 @@ class Visit extends LogTable
         return true;
     }
 
+    public function getPrimaryKey()
+    {
+        return array('idvisit');
+    }
 }
\ No newline at end of file
