@@ -242,14 +242,19 @@ $.extend(DataTable.prototype, UIControl.prototype, {
 
         var container = $('#' + self.workingDivId + ' .piwik-graph');
 
+        var ajaxRequest = new ajaxHelper();
+
+        if (self.param.totalRows) {
+            ajaxRequest.addParams({'totalRows': self.param.totalRows}, 'post');
+            delete self.param.totalRows;
+        }
+
         var params = {};
         for (var key in self.param) {
             if (typeof self.param[key] != "undefined" && self.param[key] != '')
                 params[key] = self.param[key];
         }
 
-        var ajaxRequest = new ajaxHelper();
-
         ajaxRequest.addParams(params, 'get');
         ajaxRequest.withTokenInUrl();
 
@@ -497,27 +502,13 @@ $.extend(DataTable.prototype, UIControl.prototype, {
             return parseInt(maxWidth, 10);
         }
 
-        function removePaddingFromWidth(domElem, labelWidth) {
-            var maxPaddingLeft  = 0;
-            var maxPaddingRight = 0;
+        function removePaddingFromWidth(elem, labelWidth) {
+            var paddingLeft  = elem.css('paddingLeft');
+            paddingLeft      = paddingLeft ? Math.round(parseFloat(paddingLeft)) : 0;
+            var paddingRight = elem.css('paddingRight');
+            paddingRight     = paddingRight ? Math.round(parseFloat(paddingLeft)) : 0;
 
-            $('tbody tr td.label', domElem).each(function (i, node) {
-                $node = $(node);
-
-                var paddingLeft  = $node.css('paddingLeft');
-                paddingLeft      = paddingLeft ? Math.round(parseFloat(paddingLeft)) : 0;
-                var paddingRight = $node.css('paddingRight');
-                paddingRight     = paddingRight ? Math.round(parseFloat(paddingLeft)) : 0;
-
-                if (paddingLeft > maxPaddingLeft) {
-                    maxPaddingLeft = paddingLeft;
-                }
-                if (paddingRight > maxPaddingRight) {
-                    maxPaddingRight = paddingRight;
-                }
-            });
-
-            labelWidth = labelWidth - maxPaddingLeft - maxPaddingRight;
+            labelWidth = labelWidth - paddingLeft - paddingRight;
 
             return labelWidth;
         }
@@ -531,9 +522,6 @@ $.extend(DataTable.prototype, UIControl.prototype, {
         if (isTableVisualization) {
             // we do this only for html tables
 
-            var minLabelWidth = 125;
-            var maxLabelWidth = 440;
-
             var tableWidth = getTableWidth(domElem);
             var labelColumnMinWidth = getLabelColumnMinWidth(domElem);
             var labelColumnMaxWidth = getLabelColumnMaxWidth(domElem);
@@ -546,10 +534,10 @@ $.extend(DataTable.prototype, UIControl.prototype, {
                 labelColumnWidth = labelColumnMaxWidth;
             }
 
-            labelColumnWidth = removePaddingFromWidth(domElem, labelColumnWidth);
-
             if (labelColumnWidth) {
-                $('td.label', domElem).width(labelColumnWidth);
+                $('td.label', domElem).each(function() {
+                    $(this).width(removePaddingFromWidth($(this), labelColumnWidth));
+                });
             }
 
             $('td span.label', domElem).each(function () { self.tooltip($(this)); });
@@ -603,14 +591,14 @@ $.extend(DataTable.prototype, UIControl.prototype, {
         } else {
             var inReportPage = domElem.parents('.theWidgetContent').first();
             var displayedAsCard = inReportPage.find('> .card > .card-content');
-            if (displayedAsCard.size()) {
+            if (displayedAsCard.length) {
                 $domNodeToSetOverflow = displayedAsCard.first();
             } else {
                 $domNodeToSetOverflow = inReportPage;
             }
         }
 
-        if (!$domNodeToSetOverflow || !$domNodeToSetOverflow.size()) {
+        if (!$domNodeToSetOverflow || !$domNodeToSetOverflow.length) {
             return;
         }
 
@@ -638,14 +626,14 @@ $.extend(DataTable.prototype, UIControl.prototype, {
     },
 
     handleLimit: function (domElem) {
-            var tableRowLimits = piwik.config.datatable_row_limits,
-            evolutionLimits =
-            {
-                day: [8, 30, 60, 90, 180, 365, 500],
-                week: [4, 12, 26, 52, 104, 500],
-                month: [3, 6, 12, 24, 36, 120],
-                year: [3, 5, 10]
-            };
+        var tableRowLimits = piwik.config.datatable_row_limits,
+        evolutionLimits =
+        {
+            day: [8, 30, 60, 90, 180, 365, 500],
+            week: [4, 12, 26, 52, 104, 500],
+            month: [3, 6, 12, 24, 36, 120],
+            year: [3, 5, 10]
+        };
 
         var self = this;
         if (typeof self.parentId != "undefined" && self.parentId != '') {
@@ -654,6 +642,16 @@ $.extend(DataTable.prototype, UIControl.prototype, {
             return;
         }
 
+        if (self.props.disable_all_rows_filter_limit) { // remove the -1 value from the limits array
+            var tempTableRowLimits = [];
+            tableRowLimits.forEach(function (limit) {
+                if (limit != -1) {
+                    tempTableRowLimits.push(limit);
+                }
+            });
+            tableRowLimits = tempTableRowLimits;
+        }
+
         // configure limit control
         var setLimitValue, numbers, limitParamName;
         if (self.param.viewDataTable == 'graphEvolution') {
@@ -721,6 +719,8 @@ $.extend(DataTable.prototype, UIControl.prototype, {
             }
 
             $limitSelect.material_select();
+
+            $('.limitSelection input', domElem).attr('title', _pk_translate('General_RowsToDisplay'));
         }
         else {
             $('.limitSelection', domElem).hide();
@@ -795,7 +795,7 @@ $.extend(DataTable.prototype, UIControl.prototype, {
         });
 
         var $searchAction = $('.dataTableAction.searchAction', domElem);
-        if (!$searchAction.size()) {
+        if (!$searchAction.length) {
             return;
         }
 
@@ -1180,157 +1180,6 @@ $.extend(DataTable.prototype, UIControl.prototype, {
         self.graphViewEnabled = 0;
         self.graphViewStartingThreads = 0;
         self.graphViewStartingKeep = false; //show keep flag
-
-        //handle exportToFormat icons
-        self.exportToFormat = null;
-        $('.exportToFormatIcons a', domElem).click(function () {
-            self.exportToFormat = {};
-            self.exportToFormat.lastActiveIcon = this;
-            self.exportToFormat.target = $(this).parent().siblings('.exportToFormatItems').show('fast');
-            self.exportToFormat.obj = $(this).hide();
-        });
-
-        //close exportToFormat onClickOutside
-        self._bodyMouseUp = function (e) {
-            if (self.exportToFormat) {
-                self.exportToFormatHide(domElem);
-            }
-        };
-        $('body').on('mouseup', self._bodyMouseUp);
-
-        $('.exportToFormatItems a', domElem)
-            // prevent click jacking attacks by dynamically adding the token auth when the link is clicked
-            .click(function () {
-                $(this).attr('href', function () {
-                    var url = $(this).attr('href') + '&token_auth=' + piwik.token_auth;
-
-                    var limit = $('.limitSelection>div>span', domElem).attr('value');
-                    var defaultLimit = $(this).attr('filter_limit');
-                    if (!limit || 'undefined' === limit || defaultLimit == -1) {
-                        limit = defaultLimit;
-                    }
-                    url += '&filter_limit=' + limit;
-
-                    return url;
-                })
-            })
-            .attr('href', function () {
-                var format = $(this).attr('format');
-                var method = $(this).attr('methodToCall');
-                var params = $(this).attr('requestParams');
-
-                if (params) {
-                    params = JSON.parse(params)
-                } else {
-                    params = {};
-                }
-
-                var segment = self.param.segment;
-                var label = self.param.label;
-                var idGoal = self.param.idGoal;
-                var idDimension = self.param.idDimension;
-                var param_date = self.param.date;
-                var date = $(this).attr('date');
-                if (typeof date != 'undefined') {
-                    param_date = date;
-                }
-                if (typeof self.param.dateUsedInGraph != 'undefined') {
-                    param_date = self.param.dateUsedInGraph;
-                }
-                var period = self.param.period;
-
-                var formatsUseDayNotRange = piwik.config.datatable_export_range_as_day.toLowerCase();
-                if (!format) {
-                    // eg export as image has no format
-                    return;
-                }
-
-                if (formatsUseDayNotRange.indexOf(format.toLowerCase()) != -1
-                    && self.param.period == 'range') {
-                    period = 'day';
-                }
-
-                // Below evolution graph, show daily exports
-                if(self.param.period == 'range'
-                    && self.param.viewDataTable == "graphEvolution") {
-                    period = 'day';
-                }
-
-                var str = 'index.php?module=API'
-                    + '&method=' + method
-                    + '&format=' + format
-                    + '&idSite=' + self.param.idSite
-                    + '&period=' + period
-                    + '&date=' + param_date
-                    + ( typeof self.param.filter_pattern != "undefined" ? '&filter_pattern=' + self.param.filter_pattern : '')
-                    + ( typeof self.param.filter_pattern_recursive != "undefined" ? '&filter_pattern_recursive=' + self.param.filter_pattern_recursive : '');
-
-                if ($.isPlainObject(params)) {
-                    $.each(params, function (index, param) {
-                        str += '&' + index + '=' + encodeURIComponent(param);
-                    });
-                }
-
-                if (typeof self.param.flat != "undefined") {
-                    str += '&flat=' + (self.param.flat == 0 ? '0' : '1');
-                    if (typeof self.param.include_aggregate_rows != "undefined" && self.param.include_aggregate_rows == '1') {
-                        str += '&include_aggregate_rows=1';
-                    }
-                    if (!self.param.flat
-                        && typeof self.param.filter_pattern_recursive != "undefined"
-                        && self.param.filter_pattern_recursive) {
-                        str += '&expanded=1';
-                    }
-
-                } else {
-                    str += '&expanded=1';
-                }
-                if (self.param.pivotBy) {
-                    str += '&pivotBy=' + self.param.pivotBy + '&pivotByColumnLimit=20';
-                    if (self.props.pivot_by_column) {
-                        str += '&pivotByColumn=' + self.props.pivot_by_column;
-                    }
-                }
-                if (format == 'CSV' || format == 'TSV' || format == 'RSS') {
-                    str += '&translateColumnNames=1&language=' + piwik.language;
-                }
-                if (typeof segment != 'undefined') {
-                    str += '&segment=' + segment;
-                }
-                // Export Goals specific reports
-                if (typeof idGoal != 'undefined'
-                    && idGoal != '-1') {
-                    str += '&idGoal=' + idGoal;
-                }
-                // Export Dimension specific reports
-                if (typeof idDimension != 'undefined'
-                    && idDimension != '-1') {
-                    str += '&idDimension=' + idDimension;
-                }
-                if (label) {
-                    label = label.split(',');
-
-                    if (label.length > 1) {
-                        for (var i = 0; i != label.length; ++i) {
-                            str += '&label[]=' + encodeURIComponent(label[i]);
-                        }
-                    } else {
-                        str += '&label=' + encodeURIComponent(label[0]);
-                    }
-                }
-                return str;
-            }
-        );
-    },
-
-    exportToFormatHide: function (domElem, noAnimation) {
-        var self = this;
-        if (self.exportToFormat) {
-            var animationSpeed = noAnimation ? 0 : 'fast';
-            self.exportToFormat.target.hide(animationSpeed);
-            self.exportToFormat.obj.show(animationSpeed);
-            self.exportToFormat = null;
-        }
     },
 
     handleConfigurationBox: function (domElem, callbackSuccess) {
@@ -1353,7 +1202,7 @@ $.extend(DataTable.prototype, UIControl.prototype, {
             $('.dropdownConfigureIcon', domElem).remove();
         }
 
-        if (ul.find('li').size() == 0) {
+        if (!ul.find('li').length) {
             hideConfigurationIcon();
             return;
         }
@@ -1569,57 +1418,55 @@ $.extend(DataTable.prototype, UIControl.prototype, {
         var self = this;
 
         // higlight all columns on hover
-        $('td', domElem).hover(
-            function() {
-
-                if ($(this).hasClass('label')) {
-                    return;
-                }
-
-                var table    = $(this).closest('table');
-                var nthChild = $(this).parent('tr').children().index($(this)) + 1;
-                var rows     = $('> tbody > tr', table);
-
-                if (!maxWidth[nthChild]) {
-                    maxWidth[nthChild] = 0;
-                    rows.find("td:nth-child(" + (nthChild) + ").column .value").each(function (index, element) {
-                        var width = $(element).width();
-                        if (width > maxWidth[nthChild]) {
-                            maxWidth[nthChild] = width;
-                        }
-                    });
-                    rows.find("td:nth-child(" + (nthChild) + ").column .value").each(function (index, element) {
-                        $(element).css({width: maxWidth[nthChild], display: 'inline-block'});
-                    });
-                }
-
-                if (currentNthChild === nthChild) {
-                    return;
-                }
-
-                currentNthChild = nthChild;
-
-                rows.children("td:nth-child(" + (nthChild) + ")").addClass('highlight');
-                self.repositionRowActions($(this).parent('tr'));
-            },
-            function(event) {
-
-                var table    = $(this).closest('table');
-                var tr       = $(this).parent('tr').children();
-                var nthChild = $(this).parent('tr').children().index($(this));
-                var targetTd = $(event.relatedTarget).closest('td');
-                var nthChildTarget = targetTd.parent('tr').children().index(targetTd);
-
-                if (nthChild == nthChildTarget) {
-                    return;
-                }
-
-                currentNthChild = null;
-
-                var rows     = $('tr', table);
-                rows.find("td:nth-child(" + (nthChild + 1) + ")").removeClass('highlight');
+        $('td', domElem).hover(function() {
+            var $this = $(this);
+            if ($this.hasClass('label')) {
+                return;
             }
-        );
+
+            var table    = $this.closest('table');
+            var nthChild = $this.parent('tr').children().index($(this)) + 1;
+            var rows     = $('> tbody > tr', table);
+
+            if (!maxWidth[nthChild]) {
+                maxWidth[nthChild] = 0;
+                rows.find("td:nth-child(" + (nthChild) + ").column .value").each(function (index, element) {
+                    var width = $(element).width();
+                    if (width > maxWidth[nthChild]) {
+                        maxWidth[nthChild] = width;
+                    }
+                });
+                rows.find("td:nth-child(" + (nthChild) + ").column .value").each(function (index, element) {
+                    $(element).css({width: maxWidth[nthChild], display: 'inline-block'});
+                });
+            }
+
+            if (currentNthChild === nthChild) {
+                return;
+            }
+
+            currentNthChild = nthChild;
+
+            rows.children("td:nth-child(" + (nthChild) + ")").addClass('highlight');
+            self.repositionRowActions($this.parent('tr'));
+        }, function(event) {
+            var $this = $(this);
+            var table    = $this.closest('table');
+            var $parentTr = $this.parent('tr');
+            var tr       = $parentTr.children();
+            var nthChild = $parentTr.children().index($this);
+            var targetTd = $(event.relatedTarget).closest('td');
+            var nthChildTarget = targetTd.parent('tr').children().index(targetTd);
+
+            if (nthChild == nthChildTarget) {
+                return;
+            }
+
+            currentNthChild = null;
+
+            var rows = $('tr', table);
+            rows.find("td:nth-child(" + (nthChild + 1) + ")").removeClass('highlight');
+        });
     },
 
     //behaviour for 'nested DataTable' (DataTable loaded on a click on a row)
@@ -1682,7 +1529,7 @@ $.extend(DataTable.prototype, UIControl.prototype, {
                 $(this).toggleClass('expanded');
                 self.repositionRowActions($(this));
             }
-        ).size();
+        ).length;
     },
 
     // tooltip for column documentation
@@ -1712,7 +1559,7 @@ $.extend(DataTable.prototype, UIControl.prototype, {
                 // headline
                 top = top + thPosTop;
 
-                if (th.next().size() == 0) {
+                if (!th.next().length) {
                     left = (-1 * tooltip.outerWidth()) + th.width() +
                         parseInt(th.css('padding-right'), 10);
                 }
@@ -1736,7 +1583,7 @@ $.extend(DataTable.prototype, UIControl.prototype, {
     },
 
     canHandleRowEvents: function (domElem) {
-        return domElem.find('table > tbody > tr').size() <= this.maxNumRowsToHandleEvents;
+        return domElem.find('table > tbody > tr').length <= this.maxNumRowsToHandleEvents;
     },
 
     handleRowActions: function (domElem) {
@@ -1775,19 +1622,19 @@ $.extend(DataTable.prototype, UIControl.prototype, {
             }
 
             var $headline = domElem.prev('h2');
-            if (!$headline.size()) {
+            if (!$headline.length) {
                 return;
             }
 
             var $title = $headline.find('.title:not(.ng-hide)');
-            if ($title.size()) {
+            if ($title.length) {
                 $title.text(relatedReportName);
 
                 var scope = $title.scope();
 
                 if (scope) {
                     var $doc = domElem.find('.reportDocumentation');
-                    if ($doc.size()) {
+                    if ($doc.length) {
                         scope.inlineHelp = $.trim($doc.html());
                     }
                     scope.featureName = $.trim(relatedReportName);
@@ -1866,7 +1713,7 @@ $.extend(DataTable.prototype, UIControl.prototype, {
     },
 
     handleSummaryRow: function (domElem) {
-        var details = _pk_translate('General_LearnMore', [' (<a href="http://piwik.org/faq/how-to/faq_54/" rel="noreferrer"  target="_blank">', '</a>)']);
+        var details = _pk_translate('General_LearnMore', [' (<a href="https://matomo.org/faq/how-to/faq_54/" rel="noreferrer"  target="_blank">', '</a>)']);
 
         domElem.find('tr.summaryRow').each(function () {
             var labelSpan = $(this).find('.label .value');
@@ -1918,23 +1765,44 @@ $.extend(DataTable.prototype, UIControl.prototype, {
             // show actions that are available for the row on hover
             var actionsDom = null;
 
-            tr.hover(function () {
-                    if (actionsDom === null) {
-                        // create dom nodes on the fly
-                        actionsDom = self.createRowActions(availableActionsForReport, tr, actionInstances);
-                        td.prepend(actionsDom);
-                    }
-                    // reposition and show the actions
-                    self.repositionRowActions(tr);
-                    if ($(window).width() >= 600) {
-                        actionsDom.show();
-                    }
-                },
-                function () {
+            var useTouchEvent = false;
+            var listenEvent = 'mouseenter';
+            var userAgent = String(navigator.userAgent).toLowerCase();
+            if (userAgent.match(/(iPod|iPhone|iPad|Android|IEMobile|Windows Phone)/i)) {
+                useTouchEvent = true;
+                listenEvent = 'click';
+            }
+
+            tr.on(listenEvent, function () {
+                if (useTouchEvent && actionsDom && actionsDom.prop('rowActionsVisible')) {
+                    actionsDom.prop('rowActionsVisible', false);
+                    actionsDom.hide();
+                    return;
+                }
+
+                if (actionsDom === null) {
+                    // create dom nodes on the fly
+                    actionsDom = self.createRowActions(availableActionsForReport, tr, actionInstances);
+                    td.prepend(actionsDom);
+                }
+
+                // reposition and show the actions
+                self.repositionRowActions(tr);
+                if ($(window).width() >= 600 || useTouchEvent) {
+                    actionsDom.show();
+                }
+
+                if (useTouchEvent) {
+                    actionsDom.prop('rowActionsVisible', true);
+                }
+            });
+            if (!useTouchEvent) {
+                tr.on('mouseleave', function () {
                     if (actionsDom !== null) {
                         actionsDom.hide();
                     }
                 });
+            }
         });
     },
 
