@@ -35,17 +35,39 @@ piwik.initSparklines = function() {
 };
 
 window.initializeSparklines = function () {
-    var sparklineUrlParamsToIgnore = ['module', 'action', 'idSite', 'period', 'date', 'viewDataTable'];
+    var sparklineUrlParamsToIgnore = ['module', 'action', 'idSite', 'period', 'date', 'showtitle', 'viewDataTable', 'forceView', 'random'];
 
-    $("[data-graph-id]").each(function () {
+    $('.dataTableVizEvolution[data-report]').each(function () {
         var graph = $(this);
 
+        // we search for .widget to make sure eg in the Dashboard to not update any graph of another report
+        var selectorsToFindParent = ['.widget', '[piwik-widget-container]', '.reporting-page', 'body'];
+        var index = 0, selector, parent;
+        for (index; index < selectorsToFindParent.length; index++) {
+            selector = selectorsToFindParent[index];
+            parent = graph.parents(selector).first();
+            if (parent && parent.length) {
+                break;
+            }
+        }
+
+        if (!parent || !parent.length) {
+            return;
+        }
+
+        var sparklines = parent.find('div.sparkline:not(.notLinkable)');
+
         // try to find sparklines and add them clickable behaviour
-        graph.parent().find('div.sparkline').each(function () {
+        sparklines.each(function () {
             // find the sparkline and get it's src attribute
             var sparklineUrl = $('img', this).attr('data-src');
 
+            var $this = $(this);
+
             if (sparklineUrl != "") {
+
+                $this.addClass('linked');
+
                 var params = broadcast.getValuesFromUrl(sparklineUrl);
                 for (var i = 0; i != sparklineUrlParamsToIgnore.length; ++i) {
                     delete params[sparklineUrlParamsToIgnore[i]];
@@ -60,10 +82,10 @@ window.initializeSparklines = function () {
                 }
 
                 // on click, reload the graph with the new url
-                $(this).off('click.sparkline');
-                $(this).on('click.sparkline', function () {
-                    var reportId = graph.attr('data-graph-id'),
-                        dataTable = $(require('piwik/UI').DataTable.getDataTableByReport(reportId));
+                $this.off('click.sparkline');
+                $this.on('click.sparkline', function () {
+                    var reportId = graph.attr('data-report'),
+                        dataTable = graph;
 
                     // when the metrics picker is used, the id of the data table might be updated (which is correct behavior).
                     // for example, in goal reports it might change from GoalsgetEvolutionGraph to GoalsgetEvolutionGraph1.
