@@ -74,7 +74,7 @@ class CoreUpdater extends \Piwik\Plugin
         if ($updater->getComponentUpdates() !== null) {
             if (FrontController::shouldRethrowException()) {
                 throw new Exception("Piwik and/or some plugins have been upgraded to a new version. \n" .
-                    "--> Please run the update process first. See documentation: http://piwik.org/docs/update/ \n");
+                    "--> Please run the update process first. See documentation: https://matomo.org/docs/update/ \n");
             } elseif ($module === 'API')  {
 
                 $outputFormat = strtolower(Common::getRequestVar('format', 'xml', 'string', $_GET + $_POST));
