@@ -23,7 +23,7 @@ class HtmlTable extends Visualization
 {
     const ID = 'table';
     const TEMPLATE_FILE     = "@CoreVisualizations/_dataTableViz_htmlTable.twig";
-    const FOOTER_ICON       = 'plugins/Morpheus/images/table.png';
+    const FOOTER_ICON       = 'icon-table';
     const FOOTER_ICON_TITLE = 'General_DisplaySimpleTable';
 
     public static function getDefaultConfig()
