@@ -11,6 +11,7 @@ namespace Piwik\Plugins\CoreVisualizations\Visualizations\HtmlTable;
 
 use Piwik\Common;
 use Piwik\Config as PiwikConfig;
+use Piwik\Metrics;
 use Piwik\ViewDataTable\RequestConfig as VisualizationRequestConfig;
 
 /**
@@ -33,7 +34,12 @@ class RequestConfig extends VisualizationRequestConfig
         $this->filter_limit = PiwikConfig::getInstance()->General['datatable_default_limit'];
 
         if (Common::getRequestVar('enable_filter_excludelowpop', false) == '1') {
-            $this->filter_excludelowpop       = 'nb_visits';
+            if (Common::getRequestVar('flat', 0, 'int') === 1) {
+                $this->filter_excludelowpop = 'nb_visits';
+            } else {
+                $this->filter_excludelowpop = Metrics::INDEX_NB_VISITS;
+            }
+
             $this->filter_excludelowpop_value = false;
         }
 
