@@ -178,10 +178,12 @@
 
             // manage resources
             target.on('piwikDestroyPlot', function () {
-                $(window).off('resize', this._resizeListener);
+                if (self._resizeListener) {
+                    $(window).off('resize', self._resizeListener);
+                }
                 self._plot.destroy();
                 for (var i = 0; i < $.jqplot.visiblePlots.length; i++) {
-                    if ($.jqplot.visiblePlots[i] == self._plot) {
+                    if ($.jqplot.visiblePlots[i] === self) {
                         $.jqplot.visiblePlots[i] = null;
                     }
                 }
@@ -280,7 +282,7 @@
          * creating span elements with ticks and adding their width.
          * Rendered ticks have to be visible to get their real width. But it
          * is too fast for user to notice it. If total ticks width is bigger
-         * than container width then half of ticks is beeing cut out and their
+         * than container width then half of ticks is being cut out and their
          * width is tested again. Until their total width is smaller than chart
          * div. There is a failsafe so check will be performed no more than 20
          * times, which is I think more than enough. Each tick have its own
@@ -385,27 +387,30 @@
             // TODO: this code destroys plots when a page is switched. there must be a better way of managing memory.
             if (typeof $.jqplot.visiblePlots == 'undefined') {
                 $.jqplot.visiblePlots = [];
-                $('#secondNavBar').on('piwikSwitchPage', function () {
+                var $rootScope = piwikHelper.getAngularDependency('$rootScope');
+
+                $rootScope.$on('piwikPageChange', function () {
                     for (var i = 0; i < $.jqplot.visiblePlots.length; i++) {
                         if ($.jqplot.visiblePlots[i] == null) {
                             continue;
                         }
-                        $.jqplot.visiblePlots[i].destroy();
+                        $.jqplot.visiblePlots[i].destroyPlot();
                     }
                     $.jqplot.visiblePlots = [];
                 });
             }
 
             if (typeof plot != 'undefined') {
-                $.jqplot.visiblePlots.push(plot);
+                $.jqplot.visiblePlots.push(self);
             }
         },
 
         /** Export the chart as an image */
         exportAsImage: function (container, lang) {
+            var pixelRatio = window.devicePixelRatio || 1;
             var exportCanvas = document.createElement('canvas');
-            exportCanvas.width = container.width();
-            exportCanvas.height = container.height();
+            exportCanvas.width = Math.round(container.width() * pixelRatio);
+            exportCanvas.height = Math.round(container.height() * pixelRatio);
 
             if (!exportCanvas.getContext) {
                 alert("Sorry, not supported in your browser. Please upgrade your browser :)");
@@ -424,7 +429,7 @@
                     position.left += addPosition.left;
                     position.top += addPosition.top + parseInt(parent.css('marginTop'), 10);
                 }
-                exportCtx.drawImage(canvas[0], Math.round(position.left), Math.round(position.top));
+                exportCtx.drawImage(canvas[0], Math.round(position.left * pixelRatio), Math.round(position.top * pixelRatio));
             }
 
             var exported = exportCanvas.toDataURL("image/png");
@@ -433,8 +438,8 @@
             img.src = exported;
 
             img = $(img).css({
-                width: exportCanvas.width + 'px',
-                height: exportCanvas.height + 'px'
+                width: Math.round(exportCanvas.width / pixelRatio) + 'px',
+                height: Math.round(exportCanvas.height / pixelRatio) + 'px'
             });
 
             var popover = $(document.createElement('div'));
@@ -949,7 +954,7 @@ RowEvolutionSeriesToggle.prototype.beforeReplot = function () {
         // legend will be put there
         if (this.plugins.canvasLegend.show) {
             options.gridPadding = {
-                top: 21
+                top: 21, right: 0
             };
         }
 
@@ -1192,4 +1197,4 @@ RowEvolutionSeriesToggle.prototype.beforeReplot = function () {
     $.jqplot.preInitHooks.push($.jqplot.PieLegend.init);
     $.jqplot.postDrawHooks.push($.jqplot.PieLegend.postDraw);
 
-})(jQuery, require);
\ No newline at end of file
+})(jQuery, require);
