@@ -8,10 +8,9 @@
 
 namespace Piwik\Plugins\CustomVariables\Columns;
 
-use Piwik\DataTable;
 use Piwik\Piwik;
 use Piwik\Plugin\Dimension\VisitDimension;
-use Piwik\Plugin\Segment;
+use Piwik\Plugins\CustomVariables\Segment;
 use Piwik\Plugins\CustomVariables\CustomVariables;
 
 class Base extends VisitDimension
@@ -24,7 +23,6 @@ class Base extends VisitDimension
         $segment->setType('dimension');
         $segment->setSegment('customVariable' . $segmentNameSuffix);
         $segment->setName($this->getName() . ' (' . Piwik::translate('CustomVariables_ScopeVisit') . ')');
-        $segment->setCategory('CustomVariables_CustomVariables');
         $segment->setUnionOfSegments($this->getSegmentColumns('customVariable' . $segmentNameSuffix, $numCustomVariables));
         $this->addSegment($segment);
 
@@ -32,9 +30,29 @@ class Base extends VisitDimension
         $segment->setType('dimension');
         $segment->setSegment('customVariablePage' . $segmentNameSuffix);
         $segment->setName($this->getName() . ' (' . Piwik::translate('CustomVariables_ScopePage') . ')');
-        $segment->setCategory('CustomVariables_CustomVariables');
         $segment->setUnionOfSegments($this->getSegmentColumns('customVariablePage' . $segmentNameSuffix, $numCustomVariables));
         $this->addSegment($segment);
+
+        $segmentSuffix = 'v';
+        if (strtolower($segmentNameSuffix) === 'name') {
+            $segmentSuffix = 'k';
+        }
+
+        for ($i = 1; $i <= $numCustomVariables; $i++) {
+            $segment = new Segment();
+            $segment->setSegment('customVariable' . $segmentNameSuffix . $i);
+            $segment->setSqlSegment('log_visit.custom_var_' . $segmentSuffix . $i);
+            $segment->setName(Piwik::translate('CustomVariables_ColumnCustomVariable' . $segmentNameSuffix) . ' ' . $i
+                    . ' (' . Piwik::translate('CustomVariables_ScopeVisit') . ')');
+            $this->addSegment($segment);
+
+            $segment = new Segment();
+            $segment->setSegment('customVariablePage' . $segmentNameSuffix . $i);
+            $segment->setSqlSegment('log_link_visit_action.custom_var_' . $segmentSuffix . $i);
+            $segment->setName(Piwik::translate('CustomVariables_ColumnCustomVariable' . $segmentNameSuffix) . ' ' . $i
+                    . ' (' . Piwik::translate('CustomVariables_ScopePage') . ')');
+            $this->addSegment($segment);
+        }
     }
 
     private function getSegmentColumns($column, $numCustomVariables)
