@@ -197,9 +197,11 @@
             var ajaxRequest = new ajaxHelper();
             ajaxRequest.setLoadingElement();
             ajaxRequest.addParams({
-                module: 'Dashboard',
-                action: 'removeDashboard',
-                idDashboard: dashboardId
+                module: 'API',
+                method: 'Dashboard.removeDashboard',
+                idDashboard: dashboardId,
+                login: piwik.userLogin,
+                format: 'json'
             }, 'get');
             ajaxRequest.setCallback(
                 function () {
@@ -353,7 +355,7 @@
 
         var $dashboardElement = $(' > .col', dashboardElement);
 
-        if (!$dashboardElement.size()) {
+        if (!$dashboardElement.length) {
             return;
         }
 
@@ -605,7 +607,7 @@
         $(layoutColumnSelector).each(function () {
             columns[columnNumber] = [];
             var items = $('[widgetId]', this);
-            for (var j = 0; j < items.size(); j++) {
+            for (var j = 0; j < items.length; j++) {
                 columns[columnNumber][j] = $(items[j]).dashboardWidget('getWidgetObject');
 
                 // Do not store segment in the dashboard layout
