@@ -13,21 +13,89 @@ function widgetsHelper() {
  *
  * @return {object} object containing available widgets
  */
-widgetsHelper.getAvailableWidgets = function () {
+widgetsHelper.getAvailableWidgets = function (callback) {
+
+    function mergeCategoriesAndSubCategories(availableWidgets)
+    {
+        var categorized = {};
+
+        $.each(availableWidgets, function (index, widget) {
+            var category = widget.category.name;
+
+            if (!categorized[category]) {
+                categorized[category] = {'-': []};
+            }
+
+            var subcategory = '-';
+            if (widget.subcategory && widget.subcategory.name) {
+                subcategory = widget.subcategory.name;
+            }
+
+            if (!categorized[category][subcategory]) {
+                categorized[category][subcategory] = [];
+            }
+
+            categorized[category][subcategory].push(widget);
+        });
+
+        var moved = {};
+
+        $.each(categorized, function (category, widgets) {
+            $.each(widgets, function (subcategory, subwidgets) {
+
+                var categoryToUse = category;
+                if (subwidgets.length >= 3 && subcategory !== '-') {
+                    categoryToUse = category + ' - ' + subcategory;
+                }
+
+                if (!moved[categoryToUse]) {
+                    moved[categoryToUse] = [];
+                }
+
+                $.each(subwidgets, function (index, widget) {
+                    moved[categoryToUse].push(widget);
+                });
+            });
+        });
+
+        return moved;
+    }
+
     if (!widgetsHelper.availableWidgets) {
         var ajaxRequest = new ajaxHelper();
+        ajaxRequest._mixinDefaultGetParams = function (params) {
+            return params;
+        };
         ajaxRequest.addParams({
-            module: 'Dashboard',
-            action: 'getAvailableWidgets'
+            module: 'API',
+            method: 'API.getWidgetMetadata',
+            filter_limit: '-1',
+            format: 'JSON',
+            deep: '1',
+            idSite:  piwik.idSite || broadcast.getValueFromUrl('idSite')
         }, 'get');
         ajaxRequest.setCallback(
             function (data) {
-                widgetsHelper.availableWidgets = data;
+                widgetsHelper.availableWidgets = mergeCategoriesAndSubCategories(data);
+
+                if (callback) {
+                    callback(widgetsHelper.availableWidgets);
+                }
             }
         );
+        ajaxRequest.setErrorCallback(function (deferred, status) {
+            if (status == 'abort' || !deferred || deferred.status < 400 || deferred.status >= 600) {
+                return;
+            }
+            $('#loadingError').show();
+        });
         ajaxRequest.send(true);
     }
 
+    if (callback) {
+        callback(widgetsHelper.availableWidgets);
+    }
+
     return widgetsHelper.availableWidgets;
 };
 
@@ -72,7 +140,7 @@ widgetsHelper.getWidgetNameFromUniqueId = function (uniqueId) {
  * @param {function} onWidgetLoadedCallback   callback to be executed after widget is loaded
  * @return {object}
  */
-widgetsHelper.loadWidgetAjax = function (widgetUniqueId, widgetParameters, onWidgetLoadedCallback) {
+widgetsHelper.loadWidgetAjax = function (widgetUniqueId, widgetParameters, onWidgetLoadedCallback, onWidgetErrorCallback) {
     var disableLink = broadcast.getValueFromUrl('disableLink');
     if (disableLink.length) {
         widgetParameters['disableLink'] = disableLink;
@@ -83,6 +151,9 @@ widgetsHelper.loadWidgetAjax = function (widgetUniqueId, widgetParameters, onWid
     var ajaxRequest = new ajaxHelper();
     ajaxRequest.addParams(widgetParameters, 'get');
     ajaxRequest.setCallback(onWidgetLoadedCallback);
+    if (onWidgetErrorCallback) {
+        ajaxRequest.setErrorCallback(onWidgetErrorCallback);
+    }
     ajaxRequest.setFormat('html');
     ajaxRequest.send(false);
     return ajaxRequest;
@@ -188,6 +259,7 @@ widgetsHelper.loadWidgetAjax = function (widgetUniqueId, widgetParameters, onWid
              * @return {$} category list element
              */
             function createWidgetCategoryList(widgetPreview, availableWidgets) {
+
                 var settings = widgetPreview.settings;
 
                 if (!$('.' + settings.categorylistClass, widgetPreview).length) {
@@ -197,7 +269,6 @@ widgetsHelper.loadWidgetAjax = function (widgetUniqueId, widgetParameters, onWid
                 }
 
                 for (var widgetCategory in availableWidgets) {
-
                     $('.' + settings.categorylistClass, widgetPreview).append('<li>' + widgetCategory + '</li>');
                 }
 
@@ -224,7 +295,12 @@ widgetsHelper.loadWidgetAjax = function (widgetUniqueId, widgetParameters, onWid
 
                 if ($('.' + settings.categorylistClass + ' .' + settings.choosenClass, widgetPreview).length) {
                     var position = $('.' + settings.categorylistClass + ' .' + settings.choosenClass, widgetPreview).position().top -
-                        $('.' + settings.categorylistClass, widgetPreview).position().top;
+                        $('.' + settings.categorylistClass, widgetPreview).position().top +
+                        $('.dashboard-manager .addWidget').outerHeight();
+
+                    if (!$('#content.admin').length) {
+                        position += 5; // + padding defined in dashboard view
+                    }
 
                     $('.' + settings.widgetlistClass, widgetPreview).css('top', position);
                     $('.' + settings.widgetlistClass, widgetPreview).css('marginBottom', position);
@@ -254,6 +330,8 @@ widgetsHelper.loadWidgetAjax = function (widgetUniqueId, widgetParameters, onWid
                         widgetClass += ' ' + settings.unavailableClass;
                     }
 
+                    widgetName = piwikHelper.escape(piwikHelper.htmlEntities(widgetName));
+
                     widgetList.append('<li class="' + widgetClass + '" uniqueid="' + widgetUniqueId + '">' + widgetName + '</li>');
                 }
 
@@ -275,9 +353,10 @@ widgetsHelper.loadWidgetAjax = function (widgetUniqueId, widgetParameters, onWid
                     clearTimeout(widgetPreview);
                 });
 
-                $('li:not(.' + settings.unavailableClass + ')', widgetList).on('click', function () {
+                $('li', widgetList).on('click', function () {
                     if (!$('.widgetLoading', widgetPreview).length) {
                         settings.onSelect($(this).attr('uniqueid'));
+                        $(widgetPreview).closest('.dashboard-manager').removeClass('expanded');
                         if (settings.resetOnSelect) {
                             resetWidgetPreview(widgetPreview);
                         }
@@ -314,7 +393,7 @@ widgetsHelper.loadWidgetAjax = function (widgetUniqueId, widgetParameters, onWid
              */
             function showPreview(widgetUniqueId, widgetPreview) {
                 // do not reload id widget already displayed
-                if ($('#' + widgetUniqueId, widgetPreview).length) return;
+                if ($('[id="' + widgetUniqueId + '"]', widgetPreview).length) return;
 
                 var settings = widgetPreview.settings;
 
@@ -332,12 +411,14 @@ widgetsHelper.loadWidgetAjax = function (widgetUniqueId, widgetParameters, onWid
                 previewElement.html(emptyWidgetHtml);
 
                 var onWidgetLoadedCallback = function (response) {
-                    var widgetElement = $('#' + widgetUniqueId);
+                    var widgetElement = $(document.getElementById(widgetUniqueId));
+                    // document.getElementById needed for widgets with uniqueid like widgetOpens+Contact+Form
                     $('.widgetContent', widgetElement).html($(response));
                     $('.widgetContent', widgetElement).trigger('widget:create');
                     settings.onPreviewLoaded(widgetUniqueId, widgetElement);
                     $('.' + settings.widgetpreviewClass + ' .widgetTop', widgetPreview).on('click', function () {
                         settings.onSelect(widgetUniqueId);
+                        $(widgetPreview).closest('.dashboard-manager').removeClass('expanded');
                         if (settings.resetOnSelect) {
                             resetWidgetPreview(widgetPreview);
                         }
@@ -395,19 +476,21 @@ widgetsHelper.loadWidgetAjax = function (widgetUniqueId, widgetParameters, onWid
                     this.onPreviewLoaded = this.settings.onPreviewLoaded;
                 }
 
-                availableWidgets = widgetsHelper.getAvailableWidgets();
-
-                var categoryList = createWidgetCategoryList(this, availableWidgets);
-
                 var self = this;
-                $('li', categoryList).on('mouseover', function () {
-                    var category = $(this).text();
-                    var widgets = availableWidgets[category];
-                    $('li', categoryList).removeClass(self.settings.choosenClass);
-                    $(this).addClass(self.settings.choosenClass);
-                    showWidgetList(widgets, self);
-                    createPreviewElement(self); // empty preview
+                widgetsHelper.getAvailableWidgets(function (availableWidgets) {
+
+                    var categoryList = createWidgetCategoryList(self, availableWidgets);
+
+                    $('li', categoryList).on('mouseover', function () {
+                        var category = $(this).text();
+                        var widgets = availableWidgets[category];
+                        $('li', categoryList).removeClass(self.settings.choosenClass);
+                        $(this).addClass(self.settings.choosenClass);
+                        showWidgetList(widgets, self);
+                        createPreviewElement(self); // empty preview
+                    });
                 });
+
             };
         }
     });
