@@ -15,7 +15,7 @@ abstract class Base extends \Piwik\Plugin\Report
 {
     protected function init()
     {
-        $this->category = 'General_VisitorSettings';
+        $this->categoryId = 'General_Visitors';
     }
 
     protected function getBasicDevicePluginsDisplayProperties(ViewDataTable $view)
