@@ -8,8 +8,7 @@
  */
 namespace Piwik\Plugins\DevicesDetection\Columns;
 
-use Piwik\Piwik;
-use Piwik\Plugins\DevicesDetection\Segment;
+use Piwik\Metrics\Formatter;
 use Piwik\Tracker\Request;
 use Piwik\Tracker\Visitor;
 use Piwik\Tracker\Action;
@@ -18,20 +17,16 @@ class BrowserEngine extends Base
 {
     protected $columnName = 'config_browser_engine';
     protected $columnType = 'VARCHAR(10) NULL';
+    protected $segmentName = 'browserEngine';
+    protected $nameSingular = 'DevicesDetection_BrowserEngine';
+    protected $namePlural = 'DevicesDetection_BrowserEngines';
+    protected $acceptValues = 'Trident, WebKit, Presto, Gecko, Blink, etc.';
+    protected $suggestedValuesCallback = '\DeviceDetector\Parser\Client\Browser\Engine::getAvailableEngines';
+    protected $type = self::TYPE_TEXT;
 
-    protected function configureSegments()
+    public function formatValue($value, $idSite, Formatter $formatter)
     {
-        $segment = new Segment();
-        $segment->setSegment('browserEngine');
-        $segment->setName('DevicesDetection_BrowserEngine');
-        $segment->setAcceptedValues('Trident, WebKit, Presto, Gecko, Blink, etc.');
-        $segment->setSuggestedValuesCallback('\DeviceDetector\Parser\Client\Browser\Engine::getAvailableEngines');
-        $this->addSegment($segment);
-    }
-
-    public function getName()
-    {
-        return Piwik::translate('DevicesDetection_BrowserEngine');
+        return \Piwik\Plugins\DevicesDetection\getBrowserEngineName($value);
     }
 
     /**
