@@ -8,7 +8,6 @@
  */
 namespace Piwik\Plugins\DevicesDetection\Columns;
 
-use Piwik\Piwik;
 use Piwik\Tracker\Request;
 use Piwik\Tracker\Visitor;
 use Piwik\Tracker\Action;
@@ -17,11 +16,11 @@ class DeviceModel extends Base
 {
     protected $columnName = 'config_device_model';
     protected $columnType = 'VARCHAR( 100 ) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL';
-
-    public function getName()
-    {
-        return Piwik::translate('DevicesDetection_DeviceModel');
-    }
+    protected $type = self::TYPE_TEXT;
+    protected $nameSingular = 'DevicesDetection_DeviceModel';
+    protected $namePlural = 'DevicesDetection_DeviceModels';
+    protected $segmentName = 'deviceModel';
+    protected $acceptValues = 'iPad, Nexus 5, Galaxy S5, Fire TV, etc.';
 
     /**
      * @param Request $request
