@@ -8,7 +8,6 @@
  */
 namespace Piwik\Plugins\DevicesDetection\Columns;
 
-use Piwik\Piwik;
 use Piwik\Tracker\Request;
 use Piwik\Tracker\Visitor;
 use Piwik\Tracker\Action;
@@ -17,11 +16,11 @@ class OsVersion extends Base
 {
     protected $columnName = 'config_os_version';
     protected $columnType = 'VARCHAR( 100 ) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL';
-
-    public function getName()
-    {
-        return Piwik::translate('DevicesDetection_OperatingSystemVersions');
-    }
+    protected $nameSingular = 'DevicesDetection_ColumnOperatingSystemVersion';
+    protected $namePlural = 'DevicesDetection_OperatingSystemVersions';
+    protected $segmentName = 'operatingSystemVersion';
+    protected $acceptValues = 'XP, 7, 2.3, 5.1, ...';
+    protected $type = self::TYPE_TEXT;
 
     /**
      * @param Request $request
