@@ -11,6 +11,7 @@ namespace Piwik\Plugins\DevicesDetection\Reports;
 use Piwik\Piwik;
 use Piwik\Plugin\ViewDataTable;
 use Piwik\Plugins\DevicesDetection\Columns\Os;
+use Piwik\Plugin\ReportsProvider;
 
 class GetOsFamilies extends Base
 {
@@ -20,8 +21,9 @@ class GetOsFamilies extends Base
         $this->dimension     = new Os();
         $this->name          = Piwik::translate('DevicesDetection_OperatingSystemFamilies');
         $this->documentation = ''; // TODO
-        $this->order = 3;
-        $this->widgetTitle  = 'DevicesDetection_OperatingSystemFamilies';
+        $this->order = 8;
+
+        $this->subcategoryId = 'DevicesDetection_Software';
     }
 
     public function configureView(ViewDataTable $view)
@@ -35,7 +37,7 @@ class GetOsFamilies extends Base
     public function getRelatedReports()
     {
         return array(
-            self::factory('DevicesDetection', 'getOsVersions'),
+            ReportsProvider::factory('DevicesDetection', 'getOsVersions'),
         );
     }
 
