@@ -1,8 +1,14 @@
 <?php
-
+/**
+ * Piwik - free/libre analytics platform
+ *
+ * @link http://piwik.org
+ * @license http://www.gnu.org/licenses/gpl-3.0.html GPL v3 or later
+ */
 namespace Piwik\Plugins\Diagnostics\Diagnostic;
 
-use Piwik\Filechecks;
+use Piwik\Development;
+use Piwik\FileIntegrity;
 use Piwik\Translation\Translator;
 
 /**
@@ -24,19 +30,17 @@ class FileIntegrityCheck implements Diagnostic
     {
         $label = $this->translator->translate('Installation_SystemCheckFileIntegrity');
 
-        $messages = Filechecks::getFileIntegrityInformation();
-        $ok = array_shift($messages);
-
-        if (empty($messages)) {
-            return array(DiagnosticResult::singleResult($label, DiagnosticResult::STATUS_OK));
+        if(Development::isEnabled()) {
+            return array(DiagnosticResult::singleResult($label, DiagnosticResult::STATUS_WARNING, '(Disabled in development mode)'));
         }
 
+        list($ok, $messages) = FileIntegrity::getFileIntegrityInformation();
+
         if ($ok) {
-            $status = DiagnosticResult::STATUS_WARNING;
-            return array(DiagnosticResult::singleResult($label, $status, $messages[0]));
+            return array(DiagnosticResult::singleResult($label, DiagnosticResult::STATUS_OK, implode('<br/>', $messages)));
         }
 
-        $comment = $this->translator->translate('General_FileIntegrityWarningExplanation');
+        $comment = $this->translator->translate('General_FileIntegrityWarning');
 
         // Keep only the 20 first lines else it becomes unmanageable
         if (count($messages) > 20) {
