@@ -59,6 +59,7 @@ class PhpFunctionsCheck implements Diagnostic
             'debug_backtrace',
             'create_function',
             'eval',
+            'hash',
             'gzcompress',
             'gzuncompress',
             'pack',
@@ -101,6 +102,7 @@ class PhpFunctionsCheck implements Diagnostic
             'debug_backtrace' => 'Installation_SystemCheckDebugBacktraceHelp',
             'create_function' => 'Installation_SystemCheckCreateFunctionHelp',
             'eval'            => 'Installation_SystemCheckEvalHelp',
+            'hash'            => 'Installation_SystemCheckHashHelp',
             'gzcompress'      => 'Installation_SystemCheckGzcompressHelp',
             'gzuncompress'    => 'Installation_SystemCheckGzuncompressHelp',
             'pack'            => 'Installation_SystemCheckPackHelp',
