@@ -17,6 +17,9 @@ class RevenueDiscount extends BaseConversion
 {
     protected $columnName = 'revenue_discount';
     protected $columnType = 'float default NULL';
+    protected $type = self::TYPE_MONEY;
+    protected $category = 'Goals_Ecommerce';
+    protected $nameSingular = 'General_Discount';
 
     /**
      * @param Request $request
