@@ -17,6 +17,9 @@ class RevenueTax extends BaseConversion
 {
     protected $columnName = 'revenue_tax';
     protected $columnType = 'float default NULL';
+    protected $type = self::TYPE_MONEY;
+    protected $category = 'Goals_Ecommerce';
+    protected $nameSingular = 'General_Tax';
 
     /**
      * @param Request $request
