@@ -8,9 +8,7 @@
  */
 namespace Piwik\Plugins\Events\Columns;
 
-use Piwik\Piwik;
 use Piwik\Plugin\Dimension\VisitDimension;
-use Piwik\Plugin\Segment;
 use Piwik\Tracker\Action;
 use Piwik\Tracker\Request;
 use Piwik\Tracker\Visitor;
@@ -19,22 +17,11 @@ class TotalEvents extends VisitDimension
 {
     protected $columnName = 'visit_total_events';
     protected $columnType = 'INT(11) UNSIGNED NULL';
+    protected $segmentName = 'events';
+    protected $nameSingular = 'Events_Events';
+    protected $acceptValues = 'To select all visits who triggered an Event, use: &segment=events>0';
 
-    protected function configureSegments()
-    {
-        $segment = new Segment();
-        $segment->setSegment('events');
-        $segment->setName('Events_TotalEvents');
-        $segment->setAcceptedValues('To select all visits who triggered an Event, use: &segment=events>0');
-        $segment->setCategory('General_Visit');
-        $segment->setType(Segment::TYPE_METRIC);
-        $this->addSegment($segment);
-    }
-
-    public function getName()
-    {
-        return Piwik::translate('Events_EventName');
-    }
+    protected $type = self::TYPE_NUMBER;
 
     /**
      * @param Request $request
@@ -74,4 +61,4 @@ class TotalEvents extends VisitDimension
     {
         return ($action && $action->getActionType() == Action::TYPE_EVENT);
     }
-}
\ No newline at end of file
+}
