@@ -9,7 +9,6 @@
 namespace Piwik\Plugins\Events\Reports;
 
 use Piwik\Piwik;
-use Piwik\Plugin\Report;
 use Piwik\Plugins\Events\Columns\EventName;
 
 /**
@@ -19,11 +18,11 @@ class GetNameFromCategoryId extends Base
 {
     protected function init()
     {
-        parent::init();
+        $this->categoryId = 'Events_Events';
+        $this->processedMetrics = false;
 
         $this->dimension     = new EventName();
         $this->name          = Piwik::translate('Events_EventNames');
         $this->isSubtableReport = true;
-        $this->widgetParams = array();
     }
 }
\ No newline at end of file
