@@ -23,8 +23,6 @@ class ExampleDimension extends Dimension
      * The name of the dimension which will be visible for instance in the UI of a related report and in the mobile app.
      * @return string
      */
-    public function getName()
-    {
-        return Piwik::translate('ExampleTracker_DimensionName');
-    }
+    protected $nameSingular = 'ExampleTracker_DimensionName';
+
 }
\ No newline at end of file
