@@ -8,7 +8,6 @@
  */
 namespace Piwik\Plugins\Feedback;
 
-
 /**
  *
  */
@@ -16,9 +15,9 @@ class Feedback extends \Piwik\Plugin
 {
 
     /**
-     * @see Piwik\Plugin::getListHooksRegistered
+     * @see Piwik\Plugin::registerEvents
      */
-    public function getListHooksRegistered()
+    public function registerEvents()
     {
         return array(
             'AssetManager.getStylesheetFiles'        => 'getStylesheetFiles',
@@ -30,15 +29,14 @@ class Feedback extends \Piwik\Plugin
     public function getStylesheetFiles(&$stylesheets)
     {
         $stylesheets[] = "plugins/Feedback/stylesheets/feedback.less";
-
-        $stylesheets[] = "plugins/Feedback/angularjs/ratefeature/ratefeature.less";
+        $stylesheets[] = "plugins/Feedback/angularjs/ratefeature/ratefeature.directive.less";
     }
 
     public function getJsFiles(&$jsFiles)
     {
-        $jsFiles[] = "plugins/Feedback/angularjs/ratefeature/ratefeature-model.js";
-        $jsFiles[] = "plugins/Feedback/angularjs/ratefeature/ratefeature-controller.js";
-        $jsFiles[] = "plugins/Feedback/angularjs/ratefeature/ratefeature-directive.js";
+        $jsFiles[] = "plugins/Feedback/angularjs/ratefeature/ratefeature-model.service.js";
+        $jsFiles[] = "plugins/Feedback/angularjs/ratefeature/ratefeature.controller.js";
+        $jsFiles[] = "plugins/Feedback/angularjs/ratefeature/ratefeature.directive.js";
     }
 
     public function getClientSideTranslationKeys(&$translationKeys)
