@@ -13,8 +13,7 @@ use Piwik\Piwik;
 
 class VisitsUntilConversion extends Dimension
 {
-    public function getName()
-    {
-        return Piwik::translate('Goals_VisitsUntilConv');
-    }
+    protected $type = self::TYPE_NUMBER;
+    protected $nameSingular = 'Goals_VisitsUntilConv';
+
 }
\ No newline at end of file
