@@ -26,6 +26,8 @@ class RequestConfig extends VisualizationRequestConfig
     public function __construct()
     {
         $this->disable_generic_filters = true;
+        $this->pivotBy = false;
+        $this->pivotByColumn = false;
 
         $properties = array(
             'min_growth_percent',
