@@ -84,7 +84,7 @@ class FormDatabaseSetup extends QuickForm2
         $this->addDataSource(new HTML_QuickForm2_DataSource_Array(array(
                                                                        'host'          => '127.0.0.1',
                                                                        'type'          => $defaultDatabaseType,
-                                                                       'tables_prefix' => 'piwik_',
+                                                                       'tables_prefix' => 'matomo_',
                                                                   )));
     }
 
@@ -96,7 +96,7 @@ class FormDatabaseSetup extends QuickForm2
      */
     public function createDatabaseObject()
     {
-        $dbname = $this->getSubmitValue('dbname');
+        $dbname = trim($this->getSubmitValue('dbname'));
         if (empty($dbname)) // disallow database object creation w/ no selected database
         {
             throw new Exception("No database name");
@@ -105,12 +105,15 @@ class FormDatabaseSetup extends QuickForm2
         $adapter = $this->getSubmitValue('adapter');
         $port = Adapter::getDefaultPortForAdapter($adapter);
 
+        $host = $this->getSubmitValue('host');
+        $tables_prefix = $this->getSubmitValue('tables_prefix');
+        
         $dbInfos = array(
-            'host'          => $this->getSubmitValue('host'),
+            'host'          => (is_null($host)) ? $host : trim($host),
             'username'      => $this->getSubmitValue('username'),
             'password'      => $this->getSubmitValue('password'),
             'dbname'        => $dbname,
-            'tables_prefix' => $this->getSubmitValue('tables_prefix'),
+            'tables_prefix' => (is_null($tables_prefix)) ? $tables_prefix : trim($tables_prefix),
             'adapter'       => $adapter,
             'port'          => $port,
             'schema'        => Config::getInstance()->database['schema'],
@@ -153,7 +156,7 @@ class FormDatabaseSetup extends QuickForm2
 /**
  * Validation rule that checks that the supplied DB user has enough privileges.
  *
- * The following privileges are required for Piwik to run:
+ * The following privileges are required for Matomo to run:
  * - CREATE
  * - ALTER
  * - SELECT
@@ -229,7 +232,7 @@ class Rule_checkUserPrivileges extends HTML_QuickForm2_Rule
     }
 
     /**
-     * Returns an array describing the database privileges required for Piwik to run. The
+     * Returns an array describing the database privileges required for Matomo to run. The
      * array maps privilege names with one or more SQL queries that can be used to test
      * if the current user has the privilege.
      *
@@ -262,7 +265,7 @@ class Rule_checkUserPrivileges extends HTML_QuickForm2_Rule
     }
 
     /**
-     * Returns a string description of the database privileges required for Piwik to run.
+     * Returns a string description of the database privileges required for Matomo to run.
      *
      * @return string
      */
