@@ -12,7 +12,6 @@ namespace Piwik\Plugins\Installation;
 use HTML_QuickForm2_DataSource_Array;
 use HTML_QuickForm2_Factory;
 use HTML_QuickForm2_Rule;
-use Piwik\Log;
 use Piwik\Access;
 use Piwik\Piwik;
 use Piwik\Plugins\SitesManager\API;
@@ -61,7 +60,7 @@ class FormFirstWebsiteSetup extends QuickForm2
                                1 => Piwik::translate('SitesManager_EnableEcommerce'),
                           ));
 
-        $this->addElement('submit', 'submit', array('value' => Piwik::translate('General_Next') . ' »', 'class' => 'btn btn-lg'));
+        $this->addElement('submit', 'submit', array('value' => Piwik::translate('General_Next') . ' »', 'class' => 'btn'));
 
         // default values
         $this->addDataSource(new HTML_QuickForm2_DataSource_Array(array(
