@@ -59,22 +59,24 @@ class FormSuperUser extends QuickForm2
             ));
 
         $professionalServicesNewsletter = Piwik::translate('Installation_ProfessionalServicesNewsletter',
-            array("<a href='https://piwik.org/support/?pk_medium=App_Newsletter_link&pk_source=Piwik_App&pk_campaign=App_Installation' style='color:#444;' rel='noreferrer' target='_blank'>", "</a>")
+            array("<a href='https://matomo.org/support/?pk_medium=App_Newsletter_link&pk_source=Piwik_App&pk_campaign=App_Installation' style='color:#444;' rel='noreferrer' target='_blank'>", "</a>")
         );
 
-        $currentLanguage = StaticContainer::get('Piwik\Translation\Translator')->getCurrentLanguage();
+        $privacyNoticeLink = '<a href="https://matomo.org/privacy-policy/" target="_blank" rel="noreferrer noopener">';
+        $privacyNotice = '<div class="form-help email-privacy-notice">' . Piwik::translate('Installation_EmailPrivacyNotice', [$privacyNoticeLink, '</a>'])
+            . '</div>';
 
         $this->addElement('checkbox', 'subscribe_newsletter_professionalservices', null,
             array(
-                'content' => '&nbsp;&nbsp;' . $professionalServicesNewsletter,
+                'content' => $privacyNotice . '&nbsp;&nbsp;' . $professionalServicesNewsletter
             ));
 
         $this->addElement('submit', 'submit', array('value' => Piwik::translate('General_Next') . ' »', 'class' => 'btn'));
 
         // default values
         $this->addDataSource(new HTML_QuickForm2_DataSource_Array(array(
-            'subscribe_newsletter_piwikorg' => 1,
-            'subscribe_newsletter_professionalservices' => $currentLanguage == 'de' ? 0 : 1,
+            'subscribe_newsletter_piwikorg' => 0,
+            'subscribe_newsletter_professionalservices' => 0,
         )));
     }
 }
