@@ -14,6 +14,7 @@ use Piwik\Config;
 use Piwik\FrontController;
 use Piwik\Piwik;
 use Piwik\Plugins\Installation\Exception\DatabaseConnectionFailedException;
+use Piwik\SettingsPiwik;
 use Piwik\View as PiwikView;
 
 /**
@@ -44,7 +45,7 @@ class Installation extends \Piwik\Plugin
 
         $errorMessage = $exception->getMessage();
 
-        if (Request::isApiRequest($_GET)) {
+        if (Request::isApiRequest(null)) {
             $ex = new DatabaseConnectionFailedException($errorMessage);
             throw $ex;
         }
@@ -62,6 +63,10 @@ class Installation extends \Piwik\Plugin
     {
         $general = Config::getInstance()->General;
 
+        if (!SettingsPiwik::isPiwikInstalled() && !$general['enable_installer']) {
+            throw new \Exception('Matomo is not set up yet');
+        }
+
         if (empty($general['installation_in_progress'])) {
             return;
         }
