@@ -89,7 +89,7 @@ class ServerFilesGenerator
     {
         $file = $path . '/.htaccess';
 
-        $content = "# This file is auto generated by Piwik, do not edit directly\n# Please report any issue or improvement directly to the Piwik team.\n\n" . $content;
+        $content = "# This file is auto generated by Matomo, do not edit directly\n# Please report any issue or improvement directly to the Matomo team.\n\n" . $content;
         if ($overwrite || !file_exists($file)) {
             @file_put_contents($file, $content);
         }
@@ -279,7 +279,7 @@ HTACCESS_ALLOW;
     }
 
     /**
-     * Deletes all existing .htaccess files and web.config files that Piwik may have created,
+     * Deletes all existing .htaccess files and web.config files that Matomo may have created,
      */
     public static function deleteHtAccessFiles()
     {
