@@ -9,6 +9,7 @@
 
 namespace Piwik\Plugins\Intl\Commands;
 
+use Piwik\Common;
 use Piwik\Container\StaticContainer;
 use Piwik\Development;
 use Piwik\Filesystem;
@@ -51,7 +52,7 @@ class GenerateIntl extends ConsoleCommand
         }
 
         preg_match_all("~^(.)(.*)$~u", $str, $arr);
-        return mb_strtoupper($arr[1][0], 'UTF-8').$arr[2][0];
+        return Common::mb_strtoupper($arr[1][0]).$arr[2][0];
     }
 
     protected function execute(InputInterface $input, OutputInterface $output)
@@ -265,6 +266,8 @@ class GenerateIntl extends ConsoleCommand
             $translations['Intl']['Format_Time'] = '{time}';
             $translations['Intl']['Format_Time_12'] = $calendarData['dateTimeFormats']['availableFormats']['hms'];
             $translations['Intl']['Format_Time_24'] = $calendarData['dateTimeFormats']['availableFormats']['Hms'];
+            $translations['Intl']['Format_Hour_12'] = $calendarData['dateTimeFormats']['availableFormats']['h'];
+            $translations['Intl']['Format_Hour_24'] = $calendarData['dateTimeFormats']['availableFormats']['H'];
             $translations['Intl']['Format_Date_Long'] = $calendarData['dateFormats']['full'];
             $translations['Intl']['Format_Date_Day_Month'] = $calendarData['dateTimeFormats']['availableFormats']['MMMEd'];
             $translations['Intl']['Format_Date_Short'] = $calendarData['dateFormats']['medium'];
