@@ -160,7 +160,7 @@ class CreatePull extends TranslationBase
 
         $message = implode('', $messages);
 
-        $message .= '\n\nHelp us translate Piwik in your language!\nSignup at https://www.transifex.com/piwik/piwik/\nIf you have any questions, get in touch with us at translations@piwik.org';
+        $message .= '\n\nHelp us translate Matomo in your language!\nSignup at https://www.transifex.com/matomo/matomo/\nIf you have any questions, get in touch with us at translations@matomo.org';
 
         $languageCodesTouched = array_unique($languageCodesTouched, SORT_REGULAR);
 
@@ -207,7 +207,7 @@ class CreatePull extends TranslationBase
                  -u '.$username.' \
                  --data "{\"title\":\"[automatic translation update] '.$title.'\",\"body\":\"'.$message.'\",\"head\":\"translationupdates\",\"base\":\"' . self::GIT_BASE_BRANCH . '\"}" \
                  -H "Accept: application/json" \
-                 https://api.github.com/repos/piwik/piwik/pulls');
+                 https://api.github.com/repos/matomo-org/matomo/pulls');
 
             switch ($returnCode) {
                 case 401:
