@@ -33,7 +33,6 @@ class LanguagesManager extends \Piwik\Plugin
     public function registerEvents()
     {
         return array(
-            'AssetManager.getStylesheetFiles'            => 'getStylesheetFiles',
             'AssetManager.getJavaScriptFiles'            => 'getJsFiles',
             'Config.NoConfigurationFile'                 => 'initLanguage',
             'Request.dispatchCoreAndPluginUpdatesScreen' => 'initLanguage',
@@ -45,11 +44,6 @@ class LanguagesManager extends \Piwik\Plugin
         );
     }
 
-    public function getStylesheetFiles(&$stylesheets)
-    {
-        $stylesheets[] = "plugins/Morpheus/stylesheets/base.less";
-    }
-
     public function getJsFiles(&$jsFiles)
     {
         $jsFiles[] = "plugins/LanguagesManager/angularjs/languageselector/languageselector.directive.js";
