@@ -21,7 +21,7 @@
     function getDataTableFromApiMethod(apiMethod)
     {
         var div = $(require('piwik/UI').DataTable.getDataTableByReport(apiMethod));
-        if (div.size() > 0 && div.data('uiControlObject')) {
+        if (div.length && div.data('uiControlObject')) {
             return div.data('uiControlObject');
         }
     }
@@ -111,8 +111,7 @@
 
         name: actionName,
 
-        dataTableIcon: 'plugins/Live/images/visitorlog.png',
-        dataTableIconHover: 'plugins/Live/images/visitorlog-hover.png',
+        dataTableIcon: 'icon-visitor-profile',
 
         order: 30,
 
