@@ -42,8 +42,11 @@
      *
      * @param {String} visitorId The string visitor ID.
      */
-    VisitorProfileControl.showPopover = function (visitorId) {
+    VisitorProfileControl.showPopover = function (visitorId, idSite) {
         var url = 'module=Live&action=getVisitorProfilePopup&visitorId=' + encodeURIComponent(visitorId);
+        if (idSite) {
+            url += '&idSite=' + idSite;
+        }
 
         // if there is already a map shown on the screen, do not show the map in the popup. kartograph seems
         // to only support showing one map at a time.
@@ -62,9 +65,6 @@
         _setupControl: function () {
             // focus the popup so it will accept key events
             this.$element.focus();
-
-            // highlight the first visit
-            $('.visitor-profile-visits>li:first-child', this.$element).addClass('visitor-profile-current-visit');
         },
 
         _bindEventCallbacks: function () {
@@ -73,24 +73,37 @@
 
             $element.on('click', '.visitor-profile-close', function (e) {
                 e.preventDefault();
+                try {
+                    $element.tooltip('destroy');
+                } catch (e) {}
                 Piwik_Popover.close();
                 return false;
             });
 
+            $element.on('click', '.visitor-profile-toggle-actions', function (e) {
+                e.preventDefault();
+                $(this).toggleClass('minimized');
+                if ($(this).hasClass('minimized')) {
+                    $('.visitor-profile-actions', $element).slideUp();
+                } else {
+                    $('.visitor-profile-actions', $element).slideDown();
+                }
+                return false;
+            });
+
             $element.on('click', '.visitor-profile-more-info>a', function (e) {
                 e.preventDefault();
                 self._loadMoreVisits();
                 return false;
             });
 
-            $element.on('click', '.visitor-profile-see-more-cvars>a', function (e) {
-                e.preventDefault();
-                $('.visitor-profile-extra-cvars', $element).slideToggle();
-                return false;
+            $element.on('click', '.visitor-profile-visit-title', function () {
+               $('.visitor-profile-visit-details-extended', $(this).parents('li')).slideToggle();
             });
 
-            $element.on('click', '.visitor-profile-visit-title-row', function () {
-                self._loadIndividualVisitDetails($('h2', this));
+            $element.on('click', '.visitor-profile-show-actions', function () {
+                $('.visitor-profile-actions', $(this).parents('li')).slideToggle();
+                return false;
             });
 
             $element.on('click', '.visitor-profile-prev-visitor', function (e) {
@@ -127,37 +140,7 @@
                 }
             });
 
-            // on hover, show export link (chrome won't let me do this via css :( )
-            $element.on('mouseenter mouseleave', '.visitor-profile-id', function (e) {
-                var $exportLink = $(this).find('.visitor-profile-export');
-                if ($exportLink.css('visibility') == 'hidden') {
-                    $exportLink.css('visibility', 'visible');
-                } else {
-                    $exportLink.css('visibility', 'hidden');
-                }
-            });
-
-            var tooltipIsOpened = false;
-
-            $('a', $element).on('focus', function () {
-                // see https://github.com/piwik/piwik/issues/4099
-                if (tooltipIsOpened) {
-                    $element.tooltip('close');
-                }
-            });
-
-            $element.tooltip({
-                track: true,
-                show: false,
-                hide: false,
-                content: function() {
-                    var title = $(this).attr('title');
-                    return $('<a>').text( title ).html().replace(/\n/g, '<br />');
-                },
-                tooltipClass: 'small',
-                open: function() { tooltipIsOpened = true; },
-                close: function() { tooltipIsOpened = false; }
-            });
+            initializeVisitorActions($element);
         },
 
         toggleMap: function () {
@@ -208,13 +191,15 @@
             loading.show();
 
             var ajax = new ajaxHelper();
+            ajax.removeDefaultParameter('segment');
             ajax.addParams({
                 module: 'Live',
                 action: 'getVisitList',
                 period: '',
                 date: '',
                 visitorId: $element.attr('data-visitor-id'),
-                filter_offset: $('.visitor-profile-visits>li', $element).length
+                filter_offset: $('.visitor-profile-visits>li', $element).length,
+                start_number: $('.visitor-profile-visits>li:last', $element).data('number') - 1
             }, 'GET');
             ajax.setCallback(function (response) {
                 if (response == "") { // no more visits left
@@ -240,37 +225,6 @@
             $('.visitor-profile-more-info', this.$element).html(noMoreSpan);
         },
 
-        _loadIndividualVisitDetails: function ($visitElement) {
-            var self = this,
-                $element = this.$element,
-                visitId = $visitElement.attr('data-idvisit');
-
-            $('.visitor-profile-avatar .loadingPiwik', $element).css('display', 'inline-block');
-            piwikHelper.lazyScrollTo($('.visitor-profile-avatar', $element)[0], 400);
-
-            var ajax = new ajaxHelper();
-            ajax.addParams({
-                module: 'Live',
-                action: 'getSingleVisitSummary',
-                visitId: visitId,
-                idSite: piwik.idSite
-            }, 'GET');
-            ajax.setCallback(function (response) {
-                $('.visitor-profile-avatar .loadingPiwik', $element).hide();
-
-                $('.visitor-profile-current-visit', $element).removeClass('visitor-profile-current-visit');
-                $visitElement.closest('li').addClass('visitor-profile-current-visit');
-
-                var $latestVisitSection = $('.visitor-profile-latest-visit', $element);
-                $latestVisitSection
-                    .html(response)
-                    .parent()
-                    .effect('highlight', {color: '#FFFFCB'}, 1200);
-            });
-            ajax.setFormat('html');
-            ajax.send();
-        },
-
         _loadPreviousVisitor: function () {
             this._gotoAdjacentVisitor(this.$element.attr('data-prev-visitor'));
         },
@@ -309,4 +263,4 @@
     // add the popup handler that creates a visitor profile
     broadcast.addPopoverHandler('visitorProfile', VisitorProfileControl.showPopover);
 
-})(jQuery, require);
\ No newline at end of file
+})(jQuery, require);
