@@ -25,7 +25,7 @@ class FormLogin extends QuickForm2
     function init()
     {
         $this->addElement('text', 'form_login')
-            ->addRule('required', Piwik::translate('General_Required', Piwik::translate('General_Username')));
+            ->addRule('required', Piwik::translate('General_Required', Piwik::translate('Login_LoginOrEmail')));
 
         $this->addElement('password', 'form_password')
             ->addRule('required', Piwik::translate('General_Required', Piwik::translate('General_Password')));
