@@ -24,6 +24,6 @@ return array(
         $handler->setFormatter(new ConsoleFormatter($c->get('log.console.format'), null, true, true));
         return $handler;
     },
-    'log.console.format' => '%start_tag%%level_name% [%datetime%]%end_tag% %message%' . PHP_EOL,
+    'log.console.format' => '%start_tag%%level_name% [%datetime%] %extra.request_id% %end_tag% %message%' . PHP_EOL,
 
 );
