@@ -27,6 +27,44 @@ var piwikHelper = {
         return $('<div/>').html(value).text();
     },
 
+    sendContentAsDownload: function (filename, content, mimeType) {
+        if (!mimeType) {
+            mimeType = 'text/plain';
+        }
+        function downloadFile(content)
+        {
+            var node = document.createElement('a');
+            node.style.display = 'none';
+            if ('string' === typeof content) {
+                node.setAttribute('href', 'data:' + mimeType + ';charset=utf-8,' + encodeURIComponent(content));
+            } else {
+                node.href = window.URL.createObjectURL(blob);
+            }
+            node.setAttribute('download', filename);
+            document.body.appendChild(node);
+            node.click();
+            document.body.removeChild(node);
+        }
+
+        var node;
+        if ('function' === typeof Blob) {
+            // browser supports blob
+            try {
+                var blob = new Blob([content], {type: mimeType});
+                if (window.navigator.msSaveOrOpenBlob) {
+                    window.navigator.msSaveBlob(blob, filename);
+                    return;
+                } else {
+                    downloadFile(blob);
+                    return;
+                }
+            } catch (e) {
+                downloadFile(content);
+            }
+        }
+        downloadFile(content);
+    },
+
     /**
      * a nice cross-browser logging function
      */
@@ -108,20 +146,37 @@ var piwikHelper = {
      * compiling of angular components manually.
      *
      * @param selector
+     * @param {object} options
+     * @param {object} options.scope if supplied, the given scope will be used when compiling the template. Shouldn't
+     *                               be a plain object but an actual angular scope.
+     * @param {object} options.params if supplied, the properties in this object are
+     *                               added to the new scope.
      */
-    compileAngularComponents: function (selector) {
+    compileAngularComponents: function (selector, options) {
+        options = options || {};
+
         var $element = $(selector);
 
         if (!$element.length) {
-
             return;
         }
 
-        angular.element(document).injector().invoke(function($compile) {
-            var scope = angular.element($element).scope();
-            if (scope) {
-                $compile($element)(scope);
+        angular.element(document).injector().invoke(function($compile, $rootScope) {
+            var scope = null;
+            if (options.scope) {
+                scope = options.scope;
+            } else {
+                scope = angular.element($element).scope();
             }
+            if (!scope) {
+                scope = $rootScope.$new(true);
+            }
+
+            if (options.params) {
+                $.extend(scope, options.params);
+            }
+
+            $compile($element)(scope);
         });
     },
 
@@ -182,13 +237,14 @@ var piwikHelper = {
 
     /**
      * Displays a Modal dialog. Text will be taken from the DOM node domSelector.
-     * Given callback handles will be mapped to the buttons having a role attriute
+     * Given callback handles will be mapped to the buttons having a role attribute
      *
      * Dialog will be closed when a button is clicked and callback handle will be
      * called, if one was given for the clicked role
      *
      * @param {string} domSelector   domSelector for modal window
      * @param {object} handles       callback functions for available roles
+     * @param {object} options       options for modal
      * @return {void}
      */
     modalConfirm: function(domSelector, handles, options)
@@ -236,6 +292,23 @@ var piwikHelper = {
             delete options.fixedFooter;
         }
 
+        if (options && options.extraWide) {
+            // if given, the modal will be shown larger than usual and almost consume the full width.
+            $content.addClass('modal-extra-wide');
+            delete options.extraWide;
+        }
+
+        if (options && !options.ready) {
+            options.ready = function () {
+                $(".modal.open a").focus();
+                var modalContent = $(".modal.open");
+                if (modalContent && modalContent[0]) {
+                    // make sure to scroll to the top of the content
+                    modalContent[0].scrollTop = 0;
+                }
+            };
+        }
+
         domElem.show();
         $content.openModal(options);
     },
@@ -432,7 +505,7 @@ var piwikHelper = {
     lazyScrollTo: function(elem, time, forceScroll)
     {
         var $elem = $(elem);
-        if (!$elem.size()) {
+        if (!$elem.length) {
             return;
         }
 
@@ -452,14 +525,28 @@ var piwikHelper = {
      * @param {string} textareaContent
      * @return {string}
      */
-    getApiFormatTextarea: function (textareaContent)
-    {
-        if(typeof textareaContent == 'undefined') {
+    getApiFormatTextarea: function (textareaContent) {
+        if (typeof textareaContent == 'undefined') {
             return '';
         }
         return textareaContent.trim().split("\n").join(',');
-    }
+    },
 
+    shortcuts: {},
+
+    /**
+     * Register a shortcut
+     *
+     * @param {string} key key-stroke to be registered for this shortcut
+     * @param {string } description  description to be shown in summary
+     * @param callback method called when pressing the key
+     */
+    registerShortcut: function(key, description, callback) {
+
+        piwikHelper.shortcuts[key] = description;
+
+        Mousetrap.bind(key, callback);
+    }
 };
 
 String.prototype.trim = function() {
