@@ -19,7 +19,7 @@
         $scope.idSite = piwik.broadcast.getValueFromUrl('idSite');
         $scope.url  = piwik.piwik_url;
         $scope.period = piwik.period;
-        $scope.arePiwikProAdsEnabled = piwik.config && piwik.config.are_ads_enabled;
+        $scope.areAdsForProfessionalServicesEnabled = piwik.config && piwik.config.are_ads_enabled;
 
         this.refresh = function (interval) {
             multisitesDashboardModel.refreshInterval = interval;
