@@ -15,6 +15,7 @@ use Piwik\Date;
 use Piwik\Db;
 use Piwik\Log;
 use Piwik\LogDeleter;
+use Piwik\Piwik;
 
 /**
  * Purges the log_visit, log_conversion and related tables of old visit data.
@@ -76,6 +77,22 @@ class LogDataPurger
             Log::warning($logMessage);
         }
 
+        /**
+         * Triggered when a plugin is supposed to delete log/raw data that is older than a certain amount of days.
+         *
+         * **Example**
+         *
+         *     public function deleteLogsOlderThan($dateUpperLimit, $deleteLogsOlderThan)
+         *     {
+         *         Db::query('DELETE FROM mytable WHERE creation_date < ' . $dateUpperLimit->getDateTime());
+         *     }
+         *
+         * @param \Piwik\Date $dateUpperLimit A date where visits that occur before this time should be deleted.
+         * @param int $deleteLogsOlderThan The number of days after which log entires are considered old.
+         *                                 Visits and related data whose age is greater than this number will be purged.
+         */
+        Piwik::postEvent('PrivacyManager.deleteLogsOlderThan', array($dateUpperLimit, $deleteLogsOlderThan));
+
         // optimize table overhead after deletion
         Db::optimizeTables($logTables);
     }
