@@ -10,6 +10,7 @@ namespace Piwik\Plugins\ProfessionalServices;
 
 use Piwik\Common;
 use Piwik\View;
+use Piwik\Plugin;
 
 class ProfessionalServices extends \Piwik\Plugin
 {
@@ -25,7 +26,12 @@ class ProfessionalServices extends \Piwik\Plugin
             'Template.afterGoalCannotAddNewGoal' => array('function' => 'getGoalOverviewPromo', 'after' => true),
             'Template.endGoalEditTable' => array('function' => 'getGoalFunnelOverviewPromo', 'after' => true),
             'Template.afterEventsReport' => 'getEventsPromo',
+            'Template.afterCampaignsReport' => 'getCampaignsPromo',
+            'Template.afterReferrerTypeReport' => 'getReferrerTypePromo',
             'Template.afterReferrersKeywordsReport' => 'getSearchKeywordsPerformancePromo',
+            'Template.afterCustomVariablesReport' => 'getCustomVariablesPromo',
+            'Template.afterOverlaySidebar' => 'getHeatmapPromo',
+            'Template.afterVisitorProfileOverview' => 'getSessionRecordingPromo',
         );
     }
 
@@ -48,7 +54,7 @@ class ProfessionalServices extends \Piwik\Plugin
                 $action = 'promoServices';
             }
 
-            if($action == 'rssPiwikPro') {
+            if ($action == 'rssPiwikPro') {
                 $action = 'rss';
             }
         }
@@ -60,10 +66,29 @@ class ProfessionalServices extends \Piwik\Plugin
         return $isWidget;
     }
 
+    public function getHeatmapPromo(&$out)
+    {
+        if (!$this->shouldShowPromoForPlugin('HeatmapSessionRecording')) {
+            return;
+        }
+
+        $view = new View('@ProfessionalServices/promoHeatmaps');
+        $out .= $view->render();
+    }
+
+    public function getSessionRecordingPromo(&$out)
+    {
+        if (!$this->shouldShowPromoForPlugin('HeatmapSessionRecording')) {
+            return;
+        }
+
+        $view = new View('@ProfessionalServices/promoSessionRecordings');
+        $out .= $view->render();
+    }
+
     public function getSearchKeywordsPerformancePromo(&$out)
     {
-        if(\Piwik\Plugin\Manager::getInstance()->isPluginActivated('SearchEngineKeywordsPerformance')
-            || $this->isRequestForDashboardWidget()) {
+        if (!$this->shouldShowPromoForPlugin('SearchEngineKeywordsPerformance')) {
             return;
         }
 
@@ -73,34 +98,67 @@ class ProfessionalServices extends \Piwik\Plugin
 
     public function getGoalFunnelOverviewPromo(&$out)
     {
-        if(\Piwik\Plugin\Manager::getInstance()->isPluginActivated('Funnels')
-            || $this->isRequestForDashboardWidget()) {
-            return;
+        if ($this->shouldShowPromoForPlugin('Funnels')) {
+            $view = new View('@ProfessionalServices/promoFunnel');
+            $out .= $view->render();
         }
-
-        $view = new View('@ProfessionalServices/promoFunnel');
-        $out .= $view->render();
     }
 
-
     public function getGoalOverviewPromo(&$out)
     {
-        if(\Piwik\Plugin\Manager::getInstance()->isPluginActivated('AbTesting')
-            || $this->isRequestForDashboardWidget()) {
-            return;
+        if ($this->shouldShowPromoForPlugin('AbTesting')) {
+            $view = new View('@ProfessionalServices/promoExperiments.twig');
+            $out .= $view->render();
         }
+    }
 
-        $view = new View('@ProfessionalServices/promoExperiments.twig');
-        $out .= $view->render();
+    public function getCustomVariablesPromo(&$out)
+    {
+        if ($this->shouldShowPromoForPlugin('CustomReports')) {
+            $view = new View('@ProfessionalServices/promoCustomVariables.twig');
+            $out .= $view->render();
+        }
     }
 
     public function getEventsPromo(&$out)
     {
-        if($this->isRequestForDashboardWidget()) {
+        if ($this->isRequestForDashboardWidget()) {
             return;
         }
+
         $view = new View('@ProfessionalServices/promoBelowEvents');
-        $view->displayMediaAnalyticsAd = !\Piwik\Plugin\Manager::getInstance()->isPluginActivated('MediaAnalytics');
+        $view->displayMediaAnalyticsAd = !$this->isPluginActivated('MediaAnalytics');
         $out .= $view->render();
     }
+
+    public function getCampaignsPromo(&$out)
+    {
+        if ($this->isRequestForDashboardWidget()) {
+            return;
+        }
+
+        $view = new View('@ProfessionalServices/promoBelowCampaigns');
+        $view->displayMarketingCampaignsReportingAd = !$this->isPluginActivated('MarketingCampaignsReporting');
+        $view->multiChannelConversionAttributionAd = !$this->isPluginActivated('MultiChannelConversionAttribution') && !empty($_REQUEST['idGoal']);
+        $out .= $view->render();
+    }
+
+    public function getReferrerTypePromo(&$out)
+    {
+        if ($this->shouldShowPromoForPlugin('MultiChannelConversionAttribution') && !empty($_REQUEST['idGoal'])) {
+            $view = new View('@ProfessionalServices/promoBelowReferrerTypes');
+            $out .= $view->render();
+        }
+    }
+
+    private function shouldShowPromoForPlugin($pluginName)
+    {
+        return !$this->isPluginActivated($pluginName) && !$this->isRequestForDashboardWidget();
+    }
+
+    private function isPluginActivated($pluginName)
+    {
+        return Plugin\Manager::getInstance()->isPluginActivated($pluginName);
+    }
+
 }
