@@ -22,79 +22,92 @@ class Promo
             // A/B Testing
             array(
                 'campaignContent' => 'abTesting',
-                'url' => 'https://piwik.org/recommends/ab-testing-learn-more',
+                'title' => 'A/B Testing',
+                'url' => 'https://matomo.org/recommends/ab-testing-learn-more',
                 'text' => 'Ever wondered what A/B testing is and why it is so important? Check out how you can increase conversions and sales on your website and app.'
             ),
             array(
                 'campaignContent' => 'abTesting',
-                'url' => ' https://piwik.org/recommends/ab-testing-website',
+                'title' => 'A/B Testing',
+                'url' => ' https://matomo.org/recommends/ab-testing-website',
                 'text' => 'Increase revenue and conversions by comparing different versions of your websites or apps, ad detect the winning variation that will grow your business!'
             ),
 
             // Media Analytics
             array(
                 'campaignContent' => 'mediaAnalytics',
-                'url' => 'https://piwik.org/recommends/media-analytics-website',
-                'text' => 'Ever wondered how people interact and engage with videos or audios on your website? Well now you can, and it integrates perfectly into your Piwik.',
+                'title' => 'Media Analytics',
+                'url' => 'https://matomo.org/recommends/media-analytics-website',
+                'text' => 'Ever wondered how people interact and engage with videos or audios on your website? Well now you can, and it integrates perfectly into your Matomo.',
             ),
             array(
                 'campaignContent' => 'mediaAnalytics',
-                'url' => 'https://piwik.org/recommends/media-analytics',
+                'title' => 'Media Analytics',
+                'url' => 'https://matomo.org/recommends/media-analytics',
                 'text' => 'Get powerful insights into how your audience watches your videos and listens to your audio. Media Analytics is now available on the Marketplace.',
             ),
 
             // Form
             array(
                 'campaignContent' => 'formAnalytics',
-                'url' => 'https://piwik.org/recommends/form-analytics',
+                'title' => 'Form Analytics',
+                'url' => 'https://matomo.org/recommends/form-analytics',
                 'text' => 'Increase the conversions on your online forms, by learning everything about your users behavior and their pain points on your forms',
             ),
 
             // Funnels
             array(
                 'campaignContent' => 'funnels',
-                'url' => 'https://piwik.org/recommends/conversion-funnels',
-                'text' => 'Increase your conversions, sales and revenue by understanding your conversion funnels and where your visitors drop off with Funnels for Piwik.'
+                'title' => 'Funnels',
+                'url' => 'https://matomo.org/recommends/conversion-funnels',
+                'text' => 'Increase your conversions, sales and revenue by understanding your conversion funnels and where your visitors drop off with Funnels for Matomo.'
             ),
 
             // Piwik training
             array(
                 'campaignContent' => 'userTraining',
-                'url' => 'https://piwik.org/training/?pk_campaign=' . Advertising::CAMPAIGN_NAME_PROFESSIONAL_SERVICES . '&pk_source=Piwik_App',
-                'text' => 'Want to know how to use all the exciting features in Piwik? Try a User training to be up to speed with working with Piwik.'
+                'title' => 'Training',
+                'url' => 'https://matomo.org/training/?pk_campaign=' . Advertising::CAMPAIGN_NAME_PROFESSIONAL_SERVICES . '&pk_source=Piwik_App',
+                'text' => 'Want to know how to use all the exciting features in Matomo? Try a User training to be up to speed with working with Matomo.'
             ),
             // Keywords performance
             array(
                 'campaignContent' => 'searchKeywords',
-                'url' => 'https://piwik.org/recommends/search-keywords-performance/',
-                'text' => 'Which queries caused your website to appear in search results? Improve your SEO efforts and monitor your position and performance for each Keyword directly in your Piwik reports.',
+                'title' => 'Search Keywords',
+                'url' => 'https://matomo.org/recommends/search-keywords-performance/',
+                'text' => 'Which queries caused your website to appear in search results? Improve your SEO efforts and monitor your position and performance for each Keyword directly in your Matomo reports.',
             ),
             // Roll-Up Reporting
             array(
                 'campaignContent' => 'rollUp',
-                'url' => 'https://piwik.org/recommends/roll-up-reporting/',
+                'title' => 'Roll-Up Reporting',
+                'url' => 'https://matomo.org/recommends/roll-up-reporting/',
                 'text' => 'Did you know you can aggregate the collected data across hundreds of sites and display it in a single dashboard?',
             ),
             // White label
             array(
                 'campaignContent' => 'whiteLabel',
-                'url' => 'https://piwik.org/recommends/white-label/',
-                'text' => 'Did you know you can give your clients access to their analytics reports where all Piwik-branded widgets are removed? Try the White Label product!',
+                'title' => 'White Label',
+                'url' => 'https://matomo.org/recommends/white-label/',
+                'text' => 'Did you know you can give your clients access to their analytics reports where all Matomo-branded widgets are removed? Try the White Label product!',
             ),
             // Enterprise
             array(
                 'campaignContent' => 'bringEnterpriseLevel',
-                'url' => 'https://piwik.org/recommends/enterprise/',
-                'text' => 'Bring your analytics to enterprise level. Upgrade your Piwik platform and receive access to numerous premium features and assistance from experts.'
+                'title' => 'Enterprise',
+                'url' => 'https://matomo.org/recommends/enterprise/',
+                'text' => 'Bring your analytics to enterprise level. Upgrade your Matomo platform and receive access to numerous premium features and assistance from experts.'
             ),
             array(
                 'campaignContent' => 'slowingDown',
-                'url' => 'https://piwik.org/recommends/enterprise/',
-                'text' => 'Is your Piwik slowing down? Piwik experts can help with your server setup!'
+                'title' => 'Enterprise',
+                'url' => 'https://matomo.org/recommends/enterprise/',
+                'text' => 'Is your Matomo slowing down? Matomo experts can help with your server setup!'
             ),
             array(
                 'campaignContent' => 'discoverPower',
-                'url' => 'https://piwik.org/recommends/enterprise/',
+                'title' => 'Enterprise',
+                'url' => 'https://matomo.org/recommends/enterprise/',
                 'text' => 'Discover the power of open-source combined with enterprise-grade support and premium functionalities.'
             ),
         );
