@@ -9,10 +9,16 @@
 namespace Piwik\Plugins\Referrers\Categories;
 
 use Piwik\Category\Category;
+use Piwik\Piwik;
 
 class ReferrersCategory extends Category
 {
     protected $id = 'Referrers_Referrers';
     protected $order = 15;
     protected $icon = 'icon-reporting-referer';
+
+    public function getDisplayName()
+    {
+        return Piwik::translate('Referrers_Acquisition');
+    }
 }
