@@ -12,7 +12,7 @@ abstract class Base extends \Piwik\Plugin\Report
 {
     protected function init()
     {
-        $this->category = 'Referrers_Referrers';
+        $this->categoryId = 'Referrers_Referrers';
     }
 
 }
