@@ -8,6 +8,7 @@
  */
 namespace Piwik\Plugins\Referrers\Reports;
 
+use Piwik\EventDispatcher;
 use Piwik\Piwik;
 use Piwik\Plugin\ViewDataTable;
 use Piwik\Plugins\Referrers\Columns\Campaign;
@@ -20,7 +21,7 @@ class GetCampaigns extends Base
         $this->dimension     = new Campaign();
         $this->name          = Piwik::translate('Referrers_Campaigns');
         $this->documentation = Piwik::translate('Referrers_CampaignsReportDocumentation',
-                               array('<br />', '<a href="http://piwik.org/docs/tracking-campaigns/" rel="noreferrer"  target="_blank">', '</a>'));
+                               array('<br />', '<a href="https://matomo.org/docs/tracking-campaigns/" rel="noreferrer"  target="_blank">', '</a>'));
         $this->actionToLoadSubTables = 'getKeywordsFromCampaignId';
         $this->hasGoalMetrics = true;
         $this->order = 9;
@@ -34,6 +35,20 @@ class GetCampaigns extends Base
         $view->config->addTranslation('label', $this->dimension->getName());
 
         $view->requestConfig->filter_limit = 25;
+
+        $this->configureFooterMessage($view);
     }
 
+
+    protected function configureFooterMessage(ViewDataTable $view)
+    {
+        if ($this->isSubtableReport) {
+            // no footer message for subtables
+            return;
+        }
+
+        $out = '';
+        EventDispatcher::getInstance()->postEvent('Template.afterCampaignsReport', array(&$out));
+        $view->config->show_footer_message = $out;
+    }
 }
