@@ -10,7 +10,6 @@ namespace Piwik\Plugins\Resolution\Columns;
 
 use Piwik\Piwik;
 use Piwik\Plugin\Dimension\VisitDimension;
-use Piwik\Plugins\Resolution\Segment;
 use Piwik\Tracker\Action;
 use Piwik\Tracker\Request;
 use Piwik\Tracker\Visitor;
@@ -19,15 +18,11 @@ class Resolution extends VisitDimension
 {
     protected $columnName = 'config_resolution';
     protected $columnType = 'VARCHAR(18) NULL';
-
-    protected function configureSegments()
-    {
-        $segment = new Segment();
-        $segment->setSegment('resolution');
-        $segment->setName('Resolution_ColumnResolution');
-        $segment->setAcceptedValues('1280x1024, 800x600, etc.');
-        $this->addSegment($segment);
-    }
+    protected $acceptValues = '1280x1024, 800x600, etc.';
+    protected $segmentName = 'resolution';
+    protected $nameSingular = 'Resolution_ColumnResolution';
+    protected $namePlural = 'Resolution_Resolutions';
+    protected $type = self::TYPE_TEXT;
 
     /**
      * @param Request $request
@@ -46,8 +41,4 @@ class Resolution extends VisitDimension
         return $resolution;
     }
 
-    public function getName()
-    {
-        return Piwik::translate('Resolution_ColumnResolution');
-    }
 }
\ No newline at end of file
