@@ -14,26 +14,41 @@ use Piwik\Plugins\RssWidget\RssRenderer;
 
 class RssChangelog extends \Piwik\Widget\Widget
 {
+    public static function getCategory()
+    {
+        return 'About Matomo';
+    }
+
+    public static function getName()
+    {
+        return 'Matomo Changelog';
+    }
+
     public static function configure(WidgetConfig $config)
     {
-        $config->setCategoryId('About Piwik');
-        $config->setName('Piwik Changelog');
+        $config->setCategoryId(self::getCategory());
+        $config->setName(self::getName());
+    }
+
+    private function getFeed($URL) {
+        $rss = new RssRenderer($URL);
+        $rss->setCountPosts(1);
+        $rss->showDescription(true);
+        $rss->showContent(false);
+        return $rss->get();
     }
 
     public function render()
-    {
+    {   
         try {
-            $rss = new RssRenderer('http://feeds.feedburner.com/PiwikReleases');
-            $rss->setCountPosts(1);
-            $rss->showDescription(true);
-            $rss->showContent(false);
-
-            return $rss->get();
-
+            return $this->getFeed('https://feeds.feedburner.com/PiwikReleases');
         } catch (\Exception $e) {
-
-            return $this->error($e);
-        }
+            try {
+            return $this->getFeed('http://feeds.feedburner.com/PiwikReleases');
+            } catch (\Exception $e) {
+                return $this->error($e);
+            }
+        }  
     }
 
     /**
