@@ -17,7 +17,7 @@ use Psr\Log\LoggerInterface;
  */
 class Google implements MetricsProvider
 {
-    const SEARCH_URL = 'http://www.google.com/search?hl=en&q=site%3A';
+    const SEARCH_URL = 'https://www.google.com/search?hl=en&q=site%3A';
 
     /**
      * @var LoggerInterface
