@@ -13,6 +13,7 @@ use Piwik\API\ResponseBuilder;
 use Piwik\Common;
 use Piwik\Exception\UnexpectedWebsiteFoundException;
 use Piwik\Piwik;
+use Piwik\Session;
 use Piwik\Settings\Measurable\MeasurableSettings;
 use Piwik\SettingsPiwik;
 use Piwik\Site;
@@ -130,13 +131,28 @@ class Controller extends \Piwik\Plugin\ControllerAdmin
         return file_get_contents($path . $filename);
     }
 
+    public function ignoreNoDataMessage()
+    {
+        Piwik::checkUserHasSomeViewAccess();
+
+        $session = new Session\SessionNamespace('siteWithoutData');
+        $session->ignoreMessage = true;
+        $session->setExpirationSeconds($oneHour = 60 * 60);
+
+        $url = Url::getCurrentUrlWithoutQueryString() . Url::getCurrentQueryStringWithParametersModified(array('module' => 'CoreHome', 'action' => 'index'));
+        Url::redirectToUrl($url);
+    }
+
     public function siteWithoutData()
     {
         $javascriptGenerator = new TrackerCodeGenerator();
         $piwikUrl = Url::getCurrentUrlWithoutFileName();
 
-        if (!$this->site) {
+        if (!$this->site && Piwik::hasUserSuperUserAccess()) {
             throw new UnexpectedWebsiteFoundException('Invalid site ' . $this->idSite);
+        } elseif (!$this->site) {
+            // redirect to login form
+            Piwik::checkUserHasViewAccess($this->idSite);
         }
 
         return $this->renderTemplate('siteWithoutData', array(
