@@ -268,7 +268,11 @@ class GeoIPAutoUpdater extends Task
             }
 
             $tempFile = GeoIp::getPathForGeoIpDatabase($tempFilename);
-            rename($tempFile, $oldDbFile);
+            if (@rename($tempFile, $oldDbFile) !== true) {
+                //In case the $tempfile cannot be renamed, we copy the file.
+                copy($tempFile, $oldDbFile);
+                unlink($tempFile);
+            }
 
             // delete original archive
             if ($unlink) {
@@ -354,6 +358,17 @@ class GeoIPAutoUpdater extends Task
         }
     }
 
+    /**
+     * Removes all options to disable any configured automatic updates
+     */
+    public static function clearOptions()
+    {
+        foreach (self::$urlOptions as $optionKey => $optionName) {
+            Option::delete($optionName);
+        }
+        Option::delete(self::SCHEDULE_PERIOD_OPTION_NAME);
+    }
+
     /**
      * Returns true if the auto-updater is setup to update at least one type of
      * database. False if otherwise.
@@ -485,6 +500,7 @@ class GeoIPAutoUpdater extends Task
         if ($ext != 'tar.gz'
             && $ext != 'gz'
             && $ext != 'dat.gz'
+            && $ext != 'mmdb.gz'
         ) {
             throw new \Exception(Piwik::translate('UserCountry_UnsupportedArchiveType', "'$ext'"));
         }
