@@ -117,6 +117,19 @@ abstract class LocationProvider
      */
     abstract public function isWorking();
 
+    /**
+     * Returns information about this location provider. Contains an id, title & description:
+     *
+     * array(
+     *     'id' => 'geoip2php',
+     *     'title' => '...',
+     *     'description' => '...'
+     * );
+     *
+     * @return array
+     */
+    abstract public function getInfo();
+
     /**
      * Returns an array mapping location result keys w/ bool values indicating whether
      * that information is supported by this provider. If it is not supported, that means
@@ -130,6 +143,21 @@ abstract class LocationProvider
      */
     abstract public function getSupportedLocationInfo();
 
+    /**
+     * Method called when a provider gets activated.
+     */
+    public function activate()
+    {
+    }
+
+    /**
+     * Returns if location provider should be shown.
+     */
+    public function isVisible()
+    {
+        return true;
+    }
+
     /**
      * Returns every available provider instance.
      *
@@ -200,10 +228,10 @@ abstract class LocationProvider
      *
      * An example result:
      * array(
-     *     'geoip_php' => array('id' => 'geoip_php',
+     *     'geoip2php' => array('id' => 'geoip2php',
      *                          'title' => '...',
      *                          'desc' => '...',
-     *                          'status' => GeoIp::BROKEN,
+     *                          'status' => GeoIp2::BROKEN,
      *                          'statusMessage' => '...',
      *                          'location' => '...')
      *     'geoip_serverbased' => array(...)
@@ -217,6 +245,7 @@ abstract class LocationProvider
     {
         $allInfo = array();
         foreach (self::getAllProviders() as $provider) {
+
             $info = $provider->getInfo();
 
             $status = self::INSTALLED;
@@ -249,6 +278,7 @@ abstract class LocationProvider
             $info['status'] = $status;
             $info['statusMessage'] = $statusMessage;
             $info['location'] = $location;
+            $info['isVisible'] = $provider->isVisible();
 
             $allInfo[$info['order']] = $info;
         }
@@ -273,7 +303,11 @@ abstract class LocationProvider
      */
     public static function getCurrentProviderId()
     {
-        $optionValue = Option::get(self::CURRENT_PROVIDER_OPTION_NAME);
+        try {
+            $optionValue = Option::get(self::CURRENT_PROVIDER_OPTION_NAME);
+        } catch (\Exception $e) {
+            $optionValue = false;
+        }
         return $optionValue === false ? DefaultProvider::ID : $optionValue;
     }
 
@@ -303,6 +337,9 @@ abstract class LocationProvider
             throw new Exception(
                 "Invalid provider ID '$providerId'. The provider either does not exist or is not available");
         }
+
+        $provider->activate();
+
         Option::set(self::CURRENT_PROVIDER_OPTION_NAME, $providerId);
         Cache::clearCacheGeneral();
         return $provider;
@@ -316,12 +353,12 @@ abstract class LocationProvider
      */
     public static function getProviderById($providerId)
     {
-        foreach (self::getAvailableProviders() as $provider) {
-            if ($provider->getId() == $providerId) {
+        foreach (self::getAllProviders() as $provider) {
+            if ($provider->getId() == $providerId && $provider->isAvailable()) {
                 return $provider;
             }
         }
-
+        
         return null;
     }
 
@@ -470,4 +507,3 @@ abstract class LocationProvider
         }
     }
 }
-
